#
# PySNMP MIB module FDDI-SMT73-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/FDDI-SMT73-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:12:32 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( OctetString, Integer, ObjectIdentifier, ) = mibBuilder.importSymbols("ASN1", "OctetString", "Integer", "ObjectIdentifier")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ValueSizeConstraint, ConstraintsIntersection, ValueRangeConstraint, SingleValueConstraint, ConstraintsUnion, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ValueSizeConstraint", "ConstraintsIntersection", "ValueRangeConstraint", "SingleValueConstraint", "ConstraintsUnion")
( NotificationGroup, ModuleCompliance, ) = mibBuilder.importSymbols("SNMPv2-CONF", "NotificationGroup", "ModuleCompliance")
( MibScalar, MibTable, MibTableRow, MibTableColumn, Integer32, Gauge32, Bits, Unsigned32, Counter64, TimeTicks, NotificationType, ModuleIdentity, ObjectIdentity, mib_2, MibIdentifier, iso, Counter32, IpAddress, ) = mibBuilder.importSymbols("SNMPv2-SMI", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "Integer32", "Gauge32", "Bits", "Unsigned32", "Counter64", "TimeTicks", "NotificationType", "ModuleIdentity", "ObjectIdentity", "mib-2", "MibIdentifier", "iso", "Counter32", "IpAddress")
( DisplayString, TextualConvention, ) = mibBuilder.importSymbols("SNMPv2-TC", "DisplayString", "TextualConvention")
transmission = MibIdentifier((1, 3, 6, 1, 2, 1, 10))
fddi = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 15))
fddimib = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 15, 73))
class FddiTimeNano(Integer32):
    subtypeSpec = Integer32.subtypeSpec+ValueRangeConstraint(0,2147483647)

class FddiTimeMilli(Integer32):
    subtypeSpec = Integer32.subtypeSpec+ValueRangeConstraint(0,2147483647)

class FddiResourceId(Integer32):
    subtypeSpec = Integer32.subtypeSpec+ValueRangeConstraint(0,65535)

class FddiSMTStationIdType(OctetString):
    subtypeSpec = OctetString.subtypeSpec+ValueSizeConstraint(8,8)
    fixedLength = 8

class FddiMACLongAddressType(OctetString):
    subtypeSpec = OctetString.subtypeSpec+ValueSizeConstraint(6,6)
    fixedLength = 6

fddimibSMT = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 15, 73, 1))
fddimibMAC = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 15, 73, 2))
fddimibMACCounters = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 15, 73, 3))
fddimibPATH = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 15, 73, 4))
fddimibPORT = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 15, 73, 5))
fddimibSMTNumber = MibScalar((1, 3, 6, 1, 2, 1, 10, 15, 73, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,65535))).setMaxAccess("readonly")
if mibBuilder.loadTexts: fddimibSMTNumber.setDescription("The number of SMT implementations (regardless of \n                      their current state) on this network management \n                      application entity.  The value for this variable \n                      must remain constant at least from one re- \n                      initialization of the entity's network management \n                      system to the next re-initialization.")
fddimibSMTTable = MibTable((1, 3, 6, 1, 2, 1, 10, 15, 73, 1, 2), )
if mibBuilder.loadTexts: fddimibSMTTable.setDescription('A list of SMT entries.  The number of entries \n                      shall not exceed the value of fddimibSMTNumber.')
fddimibSMTEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 15, 73, 1, 2, 1), ).setIndexNames((0, "FDDI-SMT73-MIB", "fddimibSMTIndex"))
if mibBuilder.loadTexts: fddimibSMTEntry.setDescription('An SMT entry containing information common to a \n                      given SMT.')
fddimibSMTIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 1, 2, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,65535))).setMaxAccess("readonly")
if mibBuilder.loadTexts: fddimibSMTIndex.setDescription("A unique value for each SMT.  The value for each \n                      SMT must remain constant at least from one re- \n                      initialization of the entity's network management \n                      system to the next re-initialization.")
fddimibSMTStationId = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 1, 2, 1, 2), FddiSMTStationIdType()).setMaxAccess("readonly")
if mibBuilder.loadTexts: fddimibSMTStationId.setDescription('Used to uniquely identify an FDDI station.')
fddimibSMTOpVersionId = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 1, 2, 1, 3), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,65535))).setMaxAccess("readonly")
if mibBuilder.loadTexts: fddimibSMTOpVersionId.setDescription('The version that this station is using for its \n                      operation (refer to ANSI 7.1.2.2). The value of \n                      this variable is 2 for this SMT revision.')
fddimibSMTHiVersionId = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 1, 2, 1, 4), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,65535))).setMaxAccess("readonly")
if mibBuilder.loadTexts: fddimibSMTHiVersionId.setDescription('The highest version of SMT that this station \n                      supports (refer to ANSI 7.1.2.2).')
fddimibSMTLoVersionId = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 1, 2, 1, 5), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,65535))).setMaxAccess("readonly")
if mibBuilder.loadTexts: fddimibSMTLoVersionId.setDescription('The lowest version of SMT that this station \n                      supports (refer to ANSI 7.1.2.2).')
fddimibSMTUserData = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 1, 2, 1, 6), OctetString().subtype(subtypeSpec=ValueSizeConstraint(32,32)).setFixedLength(32)).setMaxAccess("readwrite")
if mibBuilder.loadTexts: fddimibSMTUserData.setDescription('This variable contains 32 octets of user defined \n                      information. The information shall be an ASCII \n                      string.')
fddimibSMTMIBVersionId = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 1, 2, 1, 7), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,65535))).setMaxAccess("readonly")
if mibBuilder.loadTexts: fddimibSMTMIBVersionId.setDescription('The version of the FDDI MIB of this station.  The \n                      value of this variable is 1 for this SMT \n                      revision.')
fddimibSMTMACCts = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 1, 2, 1, 8), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,255))).setMaxAccess("readonly")
if mibBuilder.loadTexts: fddimibSMTMACCts.setDescription('The number of MACs in this station or \n                      concentrator.')
fddimibSMTNonMasterCts = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 1, 2, 1, 9), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,2))).setMaxAccess("readonly")
if mibBuilder.loadTexts: fddimibSMTNonMasterCts.setDescription('The value of this variable is the number of A, B, \n                      and S ports in this station or concentrator.')
fddimibSMTMasterCts = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 1, 2, 1, 10), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,255))).setMaxAccess("readonly")
if mibBuilder.loadTexts: fddimibSMTMasterCts.setDescription('The number of M Ports in a node. If the node is \n                      not a concentrator, the value of the variable is \n                      zero.')
fddimibSMTAvailablePaths = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 1, 2, 1, 11), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,7))).setMaxAccess("readonly")
if mibBuilder.loadTexts: fddimibSMTAvailablePaths.setDescription('A value that indicates the PATH types available \n                      in the station. \n \n                      The value is a sum.  This value initially takes \n                      the value zero, then for each type of PATH that \n                      this node has available, 2 raised to a power is \n                      added to the sum.  The powers are according to the \n                      following table: \n \n                               Path   Power \n                            Primary     0 \n                          Secondary     1 \n                              Local     2 \n \n                      For example, a station having Primary and Local \n                      PATHs available would have a value of 5 (2**0 + \n                      2**2).')
fddimibSMTConfigCapabilities = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 1, 2, 1, 12), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,3))).setMaxAccess("readonly")
if mibBuilder.loadTexts: fddimibSMTConfigCapabilities.setDescription("A value that indicates the configuration \n                      capabilities of a node. The 'Hold Available' bit \n                      indicates the support of the optional Hold \n                      Function, which is controlled by \n                      fddiSMTConfigPolicy.  The 'CF-Wrap-AB' bit \n                      indicates that the station has the capability of \n                      performing a wrap_ab (refer to ANSI SMT 9.7.2.2). \n \n                      The value is a sum.  This value initially takes \n                      the value zero, then for each of the configuration \n                      policies currently enforced on the node, 2 raised \n                      to a power is added to the sum.  The powers are \n                      according to the following table: \n \n                                 Policy   Power \n                          holdAvailable     0 \n                             CF-Wrap-AB     1 ")
fddimibSMTConfigPolicy = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 1, 2, 1, 13), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,1))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: fddimibSMTConfigPolicy.setDescription("A value that indicates the configuration policies \n                      currently desired in a node.  'Hold' is one of the \n                      terms used for the Hold Flag, an optional ECM flag \n                      used to enable the optional Hold policy. \n \n                      The value is a sum.  This value initially takes \n                      the value zero, then for each of the configuration \n                      policies currently enforced on the node, 2 raised \n                      to a power is added to the sum.  The powers are \n                      according to the following table: \n \n                                     Policy   Power \n                          configurationhold     0 ")
fddimibSMTConnectionPolicy = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 1, 2, 1, 14), Integer32().subtype(subtypeSpec=ValueRangeConstraint(32768,65535))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: fddimibSMTConnectionPolicy.setDescription("A value representing the connection policies in \n                      effect in a node. A station sets the corresponding \n                      bit for each of the connection types that it \n                      rejects. The letter designations, X and Y, in the \n                      'rejectX-Y' names have the following significance: \n                      X represents the PC-Type of the local PORT and Y \n                      represents the PC_Type of the adjacent PORT \n                      (PC_Neighbor). The evaluation of Connection- \n                      Policy (PC-Type, PC-Neighbor) is done to determine \n                      the setting of T- Val(3) in the PC-Signalling \n                      sequence (refer to ANSI 9.6.3). Note that Bit 15, \n                      (rejectM-M), is always set and cannot be cleared. \n \n                      The value is a sum.  This value initially takes \n                      the value zero, then for each of the connection \n                      policies currently enforced on the node, 2 raised \n                      to a power is added to the sum.  The powers are \n                      according to the following table: \n \n                             Policy   Power \n                          rejectA-A     0 \n                          rejectA-B     1 \n                          rejectA-S     2 \n                          rejectA-M     3 \n                          rejectB-A     4 \n                          rejectB-B     5 \n                          rejectB-S     6 \n                          rejectB-M     7 \n                          rejectS-A     8 \n                          rejectS-B     9 \n                          rejectS-S     10 \n                          rejectS-M     11 \n                          rejectM-A     12 \n                          rejectM-B     13 \n                          rejectM-S     14 \n                          rejectM-M     15 ")
fddimibSMTTNotify = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 1, 2, 1, 15), Integer32().subtype(subtypeSpec=ValueRangeConstraint(2,30))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: fddimibSMTTNotify.setDescription('The timer, expressed in seconds, used in the \n                      Neighbor Notification protocol. It has a range of \n                      2 seconds to 30 seconds, and its default value is \n                      30 seconds (refer to ANSI SMT 8.2).')
fddimibSMTStatRptPolicy = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 1, 2, 1, 16), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("true", 1), ("false", 2),))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: fddimibSMTStatRptPolicy.setDescription('If true, indicates that the node will generate \n                      Status Reporting Frames for its implemented events \n                      and conditions. It has an initial value of true. \n                      This variable determines the value of the \n                      SR_Enable Flag (refer to ANSI SMT 8.3.2.1).')
fddimibSMTTraceMaxExpiration = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 1, 2, 1, 17), FddiTimeMilli()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: fddimibSMTTraceMaxExpiration.setDescription('Reference Trace_Max (refer to ANSI SMT \n                      9.4.4.2.2).')
fddimibSMTBypassPresent = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 1, 2, 1, 18), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("true", 1), ("false", 2),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: fddimibSMTBypassPresent.setDescription('A flag indicating if the station has a bypass on \n                      its AB port pair.')
fddimibSMTECMState = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 1, 2, 1, 19), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5, 6, 7, 8,))).clone(namedValues=NamedValues(("ec0", 1), ("ec1", 2), ("ec2", 3), ("ec3", 4), ("ec4", 5), ("ec5", 6), ("ec6", 7), ("ec7", 8),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: fddimibSMTECMState.setDescription('Indicates the current state of the ECM state \n                      machine (refer to ANSI SMT 9.5.2).')
fddimibSMTCFState = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 1, 2, 1, 20), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13,))).clone(namedValues=NamedValues(("cf0", 1), ("cf1", 2), ("cf2", 3), ("cf3", 4), ("cf4", 5), ("cf5", 6), ("cf6", 7), ("cf7", 8), ("cf8", 9), ("cf9", 10), ("cf10", 11), ("cf11", 12), ("cf12", 13),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: fddimibSMTCFState.setDescription('The attachment configuration for the station or \n                      concentrator (refer to ANSI SMT 9.7.2.2).')
fddimibSMTRemoteDisconnectFlag = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 1, 2, 1, 21), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("true", 1), ("false", 2),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: fddimibSMTRemoteDisconnectFlag.setDescription('A flag indicating that the station was remotely \n                      disconnected from the network as a result of \n                      receiving an fddiSMTAction, disconnect (refer to \n                      ANSI SMT 6.4.5.3) in a Parameter Management Frame. \n                      A station requires a Connect Action to rejoin and \n                      clear the flag (refer to ANSI SMT 6.4.5.2).')
fddimibSMTStationStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 1, 2, 1, 22), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3,))).clone(namedValues=NamedValues(("concatenated", 1), ("separated", 2), ("thru", 3),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: fddimibSMTStationStatus.setDescription('The current status of the primary and secondary \n                      paths within this station.')
fddimibSMTPeerWrapFlag = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 1, 2, 1, 23), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("true", 1), ("false", 2),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: fddimibSMTPeerWrapFlag.setDescription('This variable assumes the value of the \n                      PeerWrapFlag in CFM (refer to ANSI SMT \n                      9.7.2.4.4).')
fddimibSMTTimeStamp = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 1, 2, 1, 24), FddiTimeMilli()).setMaxAccess("readonly")
if mibBuilder.loadTexts: fddimibSMTTimeStamp.setDescription('This variable assumes the value of TimeStamp \n                      (refer to ANSI SMT 8.3.2.1).')
fddimibSMTTransitionTimeStamp = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 1, 2, 1, 25), FddiTimeMilli()).setMaxAccess("readonly")
if mibBuilder.loadTexts: fddimibSMTTransitionTimeStamp.setDescription('This variable assumes the value of \n                      TransitionTimeStamp (refer to ANSI SMT 8.3.2.1).')
fddimibSMTStationAction = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 1, 2, 1, 26), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5, 6, 7, 8,))).clone(namedValues=NamedValues(("other", 1), ("connect", 2), ("disconnect", 3), ("path-Test", 4), ("self-Test", 5), ("disable-a", 6), ("disable-b", 7), ("disable-m", 8),))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: fddimibSMTStationAction.setDescription("This object, when read, always returns a value of \n                      other(1).  The behavior of setting this variable \n                      to each of the acceptable values is as follows: \n \n                           other(1): Results in an appropriate error. \n                           connect(2): Generates a Connect signal to ECM \n                                to begin a connection sequence. See ANSI \n                                Ref 9.4.2. \n                           disconnect(3): Generates a Disconnect signal \n                                to ECM. see ANSI Ref 9.4.2. \n                           path-Test(4): Initiates a station Path_Test. \n                                The Path_Test variable (see ANSI Ref \n                                9.4.1) is set to 'Testing'. The results \n                                of this action are not specified in this \n                                standard. \n                           self-Test(5): Initiates a station Self_Test. \n                                The results of this action are not \n                                specified in this standard. \n                           disable-a(6): Causes a PC_Disable on the A \n                                port if the A port mode is peer. \n                           disable-b(7): Causes a PC_Disable on the B \n                                port if the B port mode is peer. \n                           disable-m(8): Causes a PC_Disable on all M \n                                ports. \n \n                      Attempts to set this object to all other values \n                      results in an appropriate error.  The result of \n                      setting this variable to path-Test(4) or self- \n                      Test(5) is implementation-specific.")
fddimibMACNumber = MibScalar((1, 3, 6, 1, 2, 1, 10, 15, 73, 2, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,65535))).setMaxAccess("readonly")
if mibBuilder.loadTexts: fddimibMACNumber.setDescription("The total number of MAC implementations (across \n                      all SMTs) on this network management application \n                      entity.  The value for this variable must remain \n                      constant at least from one re-initialization of \n                      the entity's network management system to the next \n                      re-initialization.")
fddimibMACTable = MibTable((1, 3, 6, 1, 2, 1, 10, 15, 73, 2, 2), )
if mibBuilder.loadTexts: fddimibMACTable.setDescription('A list of MAC entries.  The number of entries \n                      shall not exceed the value of fddimibMACNumber.')
fddimibMACEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 15, 73, 2, 2, 1), ).setIndexNames((0, "FDDI-SMT73-MIB", "fddimibMACSMTIndex"), (0, "FDDI-SMT73-MIB", "fddimibMACIndex"))
if mibBuilder.loadTexts: fddimibMACEntry.setDescription('A MAC entry containing information common to a \n                      given MAC.')
fddimibMACSMTIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 2, 2, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,65535))).setMaxAccess("readonly")
if mibBuilder.loadTexts: fddimibMACSMTIndex.setDescription('The value of the SMT index associated with this \n                      MAC.')
fddimibMACIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 2, 2, 1, 2), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,65535))).setMaxAccess("readonly")
if mibBuilder.loadTexts: fddimibMACIndex.setDescription('Index variable for uniquely identifying the MAC \n                      object instances, which is the same as the \n                      corresponding resource index in SMT.')
fddimibMACIfIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 2, 2, 1, 3), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,65535))).setMaxAccess("readonly")
if mibBuilder.loadTexts: fddimibMACIfIndex.setDescription('The value of the MIB-II ifIndex corresponding to \n                      this MAC.  If none is applicable, 0 is returned.')
fddimibMACFrameStatusFunctions = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 2, 2, 1, 4), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,7))).setMaxAccess("readonly")
if mibBuilder.loadTexts: fddimibMACFrameStatusFunctions.setDescription("Indicates the MAC's optional Frame Status \n                      processing functions. \n \n                      The value is a sum.  This value initially takes \n                      the value zero, then for each function present, 2 \n                      raised to a power is added to the sum.  The powers \n                      are according to the following table: \n \n                           function   Power \n                       fs-repeating     0 \n                         fs-setting     1 \n                        fs-clearing     2 ")
fddimibMACTMaxCapability = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 2, 2, 1, 5), FddiTimeNano()).setMaxAccess("readonly")
if mibBuilder.loadTexts: fddimibMACTMaxCapability.setDescription('Indicates the maximum time value of fddiMACTMax \n                      that this MAC can support.')
fddimibMACTVXCapability = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 2, 2, 1, 6), FddiTimeNano()).setMaxAccess("readonly")
if mibBuilder.loadTexts: fddimibMACTVXCapability.setDescription('Indicates the maximum time value of \n                      fddiMACTvxValue that this MAC can support.')
fddimibMACAvailablePaths = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 2, 2, 1, 7), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,7))).setMaxAccess("readonly")
if mibBuilder.loadTexts: fddimibMACAvailablePaths.setDescription('Indicates the paths available for this MAC (refer \n                      to ANSI SMT 9.7.7). \n \n                      The value is a sum.  This value initially takes \n                      the value zero, then for each type of PATH that \n                      this MAC has available, 2 raised to a power is \n                      added to the sum.  The powers are according to the \n                      following table: \n \n                               Path   Power \n                            Primary     0 \n                          Secondary     1 \n                              Local     2 ')
fddimibMACCurrentPath = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 2, 2, 1, 8), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5, 6,))).clone(namedValues=NamedValues(("isolated", 1), ("local", 2), ("secondary", 3), ("primary", 4), ("concatenated", 5), ("thru", 6),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: fddimibMACCurrentPath.setDescription('Indicates the Path into which this MAC is \n                      currently inserted (refer to ANSI 9.7.7).')
fddimibMACUpstreamNbr = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 2, 2, 1, 9), FddiMACLongAddressType()).setMaxAccess("readonly")
if mibBuilder.loadTexts: fddimibMACUpstreamNbr.setDescription("The MAC's upstream neighbor's long individual MAC \n                      address. It has an initial value of the SMT- \n                      Unknown-MAC Address and is only modified as \n                      specified by the Neighbor Information Frame \n                      protocol (refer to ANSI SMT 7.2.1 and 8.2).")
fddimibMACDownstreamNbr = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 2, 2, 1, 10), FddiMACLongAddressType()).setMaxAccess("readonly")
if mibBuilder.loadTexts: fddimibMACDownstreamNbr.setDescription("The MAC's downstream neighbor's long individual \n                      MAC address. It has an initial value of the SMT- \n                      Unknown-MAC Address and is only modified as \n                      specified by the Neighbor Information Frame \n                      protocol (refer to ANSI SMT 7.2.1 and 8.2).")
fddimibMACOldUpstreamNbr = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 2, 2, 1, 11), FddiMACLongAddressType()).setMaxAccess("readonly")
if mibBuilder.loadTexts: fddimibMACOldUpstreamNbr.setDescription("The previous value of the MAC's upstream \n                      neighbor's long individual MAC address. It has an \n                      initial value of the SMT-Unknown- MAC Address and \n                      is only modified as specified by the Neighbor \n                      Information Frame protocol (refer to ANSI SMT \n                      7.2.1 and 8.2).")
fddimibMACOldDownstreamNbr = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 2, 2, 1, 12), FddiMACLongAddressType()).setMaxAccess("readonly")
if mibBuilder.loadTexts: fddimibMACOldDownstreamNbr.setDescription("The previous value of the MAC's downstream \n                      neighbor's long individual MAC address. It has an \n                      initial value of the SMT- Unknown-MAC Address and \n                      is only modified as specified by the Neighbor \n                      Information Frame protocol (refer to ANSI SMT \n                      7.2.1 and 8.2).")
fddimibMACDupAddressTest = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 2, 2, 1, 13), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3,))).clone(namedValues=NamedValues(("none", 1), ("pass", 2), ("fail", 3),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: fddimibMACDupAddressTest.setDescription('The Duplicate Address Test flag, Dup_Addr_Test \n                      (refer to ANSI 8.2).')
fddimibMACRequestedPaths = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 2, 2, 1, 14), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,255))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: fddimibMACRequestedPaths.setDescription('List of permitted Paths which specifies the \n                      Path(s) into which the MAC may be inserted (refer \n                      to ansi SMT 9.7). \n \n                      The value is a sum which represents the individual \n                      paths that are desired.  This value initially \n                      takes the value zero, then for each type of PATH \n                      that this node is, 2 raised to a power is added to \n                      the sum.  The powers are according to the \n                      following table: \n \n                                         Path   Power \n                                        local     0 \n                          secondary-alternate     1 \n                            primary-alternate     2 \n                       concatenated-alternate     3 \n                          secondary-preferred     4 \n                            primary-preferred     5 \n                       concatenated-preferred     6 \n                                         thru     7 ')
fddimibMACDownstreamPORTType = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 2, 2, 1, 15), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5,))).clone(namedValues=NamedValues(("a", 1), ("b", 2), ("s", 3), ("m", 4), ("none", 5),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: fddimibMACDownstreamPORTType.setDescription('Indicates the PC-Type of the first port that is \n                      downstream of this MAC (the exit port).')
fddimibMACSMTAddress = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 2, 2, 1, 16), FddiMACLongAddressType()).setMaxAccess("readonly")
if mibBuilder.loadTexts: fddimibMACSMTAddress.setDescription('The 48-bit individual address of the MAC used for \n                      SMT frames.')
fddimibMACTReq = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 2, 2, 1, 17), FddiTimeNano()).setMaxAccess("readonly")
if mibBuilder.loadTexts: fddimibMACTReq.setDescription('This variable is the T_Req_value passed to the \n                      MAC.  Without having detected a duplicate, the \n                      time value of this variable shall assume the \n                      maximum supported time value which is less than or \n                      equal to the time value of fddiPATHMaxT-Req.  When \n                      a MAC has an address detected as a duplicate, it \n                      may use a time value for this variable greater \n                      than the time value of fddiPATHTMaxLowerBound.  A \n                      station shall cause claim when the new T_Req may \n                      cause the value of T_Neg to change in the claim \n                      process, (i.e., time value new T_Req < T_Neg, or \n                      old T_Req = T_Neg).')
fddimibMACTNeg = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 2, 2, 1, 18), FddiTimeNano()).setMaxAccess("readonly")
if mibBuilder.loadTexts: fddimibMACTNeg.setDescription('It is reported as a FddiTimeNano number.')
fddimibMACTMax = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 2, 2, 1, 19), FddiTimeNano()).setMaxAccess("readonly")
if mibBuilder.loadTexts: fddimibMACTMax.setDescription('This variable is the T_Max_value passed to the \n                      MAC.  The time value of this variable shall assume \n                      the minimum suported time value which is greater \n                      than or equal to the time value of fddiPATHT- \n                      MaxLowerBound')
fddimibMACTvxValue = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 2, 2, 1, 20), FddiTimeNano()).setMaxAccess("readonly")
if mibBuilder.loadTexts: fddimibMACTvxValue.setDescription('This variable is the TVX_value passed to the MAC. \n                      The time value of this variable shall assume the \n                      minimum suported time value which is greater than \n                      or equal to the time value of \n                      fddiPATHTVXLowerBound.')
fddimibMACFrameCts = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 2, 2, 1, 21), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: fddimibMACFrameCts.setDescription('A count of the number of frames received by this \n                      MAC (refer to ANSI MAC 7.5.1).')
fddimibMACCopiedCts = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 2, 2, 1, 22), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: fddimibMACCopiedCts.setDescription("A count that should as closely as possible match \n                      the number of frames addressed to (A bit set) and \n                      successfully copied into the station's receive \n                      buffers (C bit set) by this MAC (refer to ANSI MAC \n                      7.5). Note that this count does not include MAC \n                      frames.")
fddimibMACTransmitCts = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 2, 2, 1, 23), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: fddimibMACTransmitCts.setDescription('A count that should as closely as possible match \n                      the number of frames transmitted by this MAC \n                      (refer to ANSI MAC 7.5).  Note that this count \n                      does not include MAC frames.')
fddimibMACErrorCts = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 2, 2, 1, 24), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: fddimibMACErrorCts.setDescription('A count of the number of frames that were \n                      detected in error by this MAC that had not been \n                      detected in error by another MAC (refer to ANSI \n                      MAC 7.5.2).')
fddimibMACLostCts = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 2, 2, 1, 25), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: fddimibMACLostCts.setDescription('A count of the number of instances that this MAC \n                      detected a format error during frame reception \n                      such that the frame was stripped (refer to ANSI \n                      MAC 7.5.3).')
fddimibMACFrameErrorThreshold = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 2, 2, 1, 26), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,65535))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: fddimibMACFrameErrorThreshold.setDescription('A threshold for determining when a MAC Condition \n                      report (see ANSI 8.3.1.1) shall be generated. \n                      Stations not supporting variable thresholds shall \n                      have a value of 0 and a range of (0..0).')
fddimibMACFrameErrorRatio = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 2, 2, 1, 27), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,65535))).setMaxAccess("readonly")
if mibBuilder.loadTexts: fddimibMACFrameErrorRatio.setDescription('This variable is the value of the ratio, \n \n                       ((delta fddiMACLostCts + delta fddiMACErrorCts) / \n                       (delta fddiMACFrameCts + delta fddiMACLostCts )) \n                       * 2**16 ')
fddimibMACRMTState = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 2, 2, 1, 28), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5, 6, 7, 8,))).clone(namedValues=NamedValues(("rm0", 1), ("rm1", 2), ("rm2", 3), ("rm3", 4), ("rm4", 5), ("rm5", 6), ("rm6", 7), ("rm7", 8),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: fddimibMACRMTState.setDescription('Indicates the current state of the RMT State \n                      Machine (refer to ANSI 10.3.2).')
fddimibMACDaFlag = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 2, 2, 1, 29), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("true", 1), ("false", 2),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: fddimibMACDaFlag.setDescription('The RMT flag Duplicate Address Flag, DA_Flag \n                      (refer to ANSI 10.2.1.2).')
fddimibMACUnaDaFlag = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 2, 2, 1, 30), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("true", 1), ("false", 2),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: fddimibMACUnaDaFlag.setDescription('A flag, UNDA_Flag (refer to ANSI 8.2.2.1), set \n                      when the upstream neighbor reports a duplicate \n                      address condition. Cleared when the condition \n                      clears.')
fddimibMACFrameErrorFlag = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 2, 2, 1, 31), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("true", 1), ("false", 2),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: fddimibMACFrameErrorFlag.setDescription('Indicates the MAC Frame Error Condition is \n                      present when set. Cleared when the condition \n                      clears and on station initialization.')
fddimibMACMAUnitdataAvailable = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 2, 2, 1, 32), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("true", 1), ("false", 2),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: fddimibMACMAUnitdataAvailable.setDescription('This variable shall take on the value of the \n                      MAC_Avail flag defined in RMT.')
fddimibMACHardwarePresent = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 2, 2, 1, 33), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("true", 1), ("false", 2),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: fddimibMACHardwarePresent.setDescription('This variable indicates the presence of \n                      underlying hardware support for this MAC object. \n                      If the value of this object is false(2), the \n                      reporting of the objects in this entry may be \n                      handled in an implementation-specific manner.')
fddimibMACMAUnitdataEnable = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 2, 2, 1, 34), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("true", 1), ("false", 2),))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: fddimibMACMAUnitdataEnable.setDescription('This variable determines the value of the \n                      MA_UNITDATA_Enable flag in RMT.  The default and \n                      initial value of this flag is true(1).')
fddimibMACCountersTable = MibTable((1, 3, 6, 1, 2, 1, 10, 15, 73, 3, 1), )
if mibBuilder.loadTexts: fddimibMACCountersTable.setDescription('A list of MAC Counters entries.  The number of \n                      entries shall not exceed the value of \n                      fddimibMACNumber.')
fddimibMACCountersEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 15, 73, 3, 1, 1), ).setIndexNames((0, "FDDI-SMT73-MIB", "fddimibMACSMTIndex"), (0, "FDDI-SMT73-MIB", "fddimibMACIndex"))
if mibBuilder.loadTexts: fddimibMACCountersEntry.setDescription('A MAC Counters entry containing information \n                      common to a given MAC.')
fddimibMACTokenCts = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 3, 1, 1, 1), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: fddimibMACTokenCts.setDescription('A count that should as closely as possible match \n                      the number of times the station has received a \n                      token (total of non-restricted and restricted) on \n                      this MAC (see ANSI MAC 7.4). This count is \n                      valuable for determination of network load.')
fddimibMACTvxExpiredCts = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 3, 1, 1, 2), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: fddimibMACTvxExpiredCts.setDescription('A count that should as closely as possible match \n                      the number of times that TVX has expired.')
fddimibMACNotCopiedCts = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 3, 1, 1, 3), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: fddimibMACNotCopiedCts.setDescription('A count that should as closely as possible match \n                      the number of frames that were addressed to this \n                      MAC but were not copied into its receive buffers \n                      (see ANSI MAC 7.5). For example, this might occur \n                      due to local buffer congestion. Because of \n                      implementation considerations, this count may not \n                      match the actual number of frames not copied. It \n                      is not a requirement that this count be exact. \n                      Note that this count does not include MAC frames.')
fddimibMACLateCts = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 3, 1, 1, 4), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: fddimibMACLateCts.setDescription('A count that should as closely as possible match \n                      the number of TRT expirations since this MAC was \n                      reset or a token was received (refer to ANSI MAC \n                      7.4.5).')
fddimibMACRingOpCts = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 3, 1, 1, 5), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: fddimibMACRingOpCts.setDescription("The count of the number of times the ring has \n                      entered the 'Ring_Operational' state from the \n                      'Ring Not Operational' state.  This count is \n                      updated when a SM_MA_STATUS.Indication of a change \n                      in the Ring_Operational status occurs (refer to \n                      ANSI 6.1.4). Because of implementation \n                      considerations, this count may be less than the \n                      actual RingOp_Ct. It is not a requirement that \n                      this count be exact.")
fddimibMACNotCopiedRatio = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 3, 1, 1, 6), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,65535))).setMaxAccess("readonly")
if mibBuilder.loadTexts: fddimibMACNotCopiedRatio.setDescription('This variable is the value of the ratio: \n \n                       (delta fddiMACNotCopiedCts / \n                       (delta fddiMACCopiedCts + \n                         delta fddiMACNotCopiedCts )) * 2**16 ')
fddimibMACNotCopiedFlag = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 3, 1, 1, 7), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("true", 1), ("false", 2),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: fddimibMACNotCopiedFlag.setDescription('Indicates that the Not Copied condition is \n                      present when read as true(1).  Set to false(2) \n                      when the condition clears and on station \n                      initialization.')
fddimibMACNotCopiedThreshold = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 3, 1, 1, 8), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,65535))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: fddimibMACNotCopiedThreshold.setDescription('A threshold for determining when a MAC condition \n                      report shall be generated.  Stations not \n                      supporting variable thresholds shall have a value \n                      of 0 and a range of (0..0).')
fddimibPATHNumber = MibScalar((1, 3, 6, 1, 2, 1, 10, 15, 73, 4, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,65535))).setMaxAccess("readonly")
if mibBuilder.loadTexts: fddimibPATHNumber.setDescription("The total number of PATHs possible (across all \n                      SMTs) on this network management application \n                      entity.  The value for this variable must remain \n                      constant at least from one re-initialization of \n                      the entity's network management system to the next \n                      re-initialization.")
fddimibPATHTable = MibTable((1, 3, 6, 1, 2, 1, 10, 15, 73, 4, 2), )
if mibBuilder.loadTexts: fddimibPATHTable.setDescription('A list of PATH entries.  The number of entries \n                      shall not exceed the value of fddimibPATHNumber.')
fddimibPATHEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 15, 73, 4, 2, 1), ).setIndexNames((0, "FDDI-SMT73-MIB", "fddimibPATHSMTIndex"), (0, "FDDI-SMT73-MIB", "fddimibPATHIndex"))
if mibBuilder.loadTexts: fddimibPATHEntry.setDescription('A PATH entry containing information common to a \n                      given PATH.')
fddimibPATHSMTIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 4, 2, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,65535))).setMaxAccess("readonly")
if mibBuilder.loadTexts: fddimibPATHSMTIndex.setDescription('The value of the SMT index associated with this \n                      PATH.')
fddimibPATHIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 4, 2, 1, 2), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,65535))).setMaxAccess("readonly")
if mibBuilder.loadTexts: fddimibPATHIndex.setDescription('Index variable for uniquely identifying the \n                      primary, secondary and local PATH object \n                      instances. Local PATH object instances are \n                      represented with integer values 3 to 255.')
fddimibPATHTVXLowerBound = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 4, 2, 1, 3), FddiTimeNano()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: fddimibPATHTVXLowerBound.setDescription('Specifies the minimum time value of \n                      fddiMACTvxValue that shall be used by any MAC that \n                      is configured in this path. The operational value \n                      of fddiMACTvxValue is managed by settting this \n                      variable.  This variable has the time value range \n                      of: \n \n                      0 < fddimibPATHTVXLowerBound < fddimibPATHMaxTReq \n                      Changes to this variable shall either satisfy the \n                      time value relationship: \n \n                      fddimibPATHTVXLowerBound <= \n                      fddimibMACTVXCapability \n \n                      of each of the MACs currently on the path, or be \n                      considered out of range.  The initial value of \n                      fddimibPATHTVXLowerBound shall be 2500 nsec (2.5 \n                      ms).')
fddimibPATHTMaxLowerBound = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 4, 2, 1, 4), FddiTimeNano()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: fddimibPATHTMaxLowerBound.setDescription('Specifies the minimum time value of fddiMACTMax \n                      that shall be used by any MAC that is configured \n                      in this path.  The operational value of \n                      fddiMACTMax is managed by setting this variable. \n                      This variable has the time value range of: \n \n                      fddimibPATHMaxTReq <= fddimibPATHTMaxLowerBound \n \n                      and an absolute time value range of: \n \n                      10000nsec (10 msec) <= fddimibPATHTMaxLowerBound \n \n                      Changes to this variable shall either satisfy the \n                      time value relationship: \n \n                      fddimibPATHTMaxLowerBound < \n                      fddimibMACTMaxCapability \n \n                      of each of the MACs currently on the path, or be \n                      considered out of range.  The initial value of \n                      fddimibPATHTMaxLowerBound shall be 165000 nsec \n                      (165 msec).')
fddimibPATHMaxTReq = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 4, 2, 1, 5), FddiTimeNano()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: fddimibPATHMaxTReq.setDescription('Specifies the maximum time value of fddiMACT-Req \n                      that shall be used by any MAC that is configured \n                      in this path.  The operational value of fddiMACT- \n                      Req is managed by setting this variable.  This \n                      variable has the time value range of: \n \n                      fddimibPATHTVXLowerBound < fddimibPATHMaxTReq <= \n                                               fddimibPATHTMaxLowerBound. \n \n                      The default value of fddimibPATHMaxTReq is 165000 \n                      nsec (165 msec).')
fddimibPATHConfigTable = MibTable((1, 3, 6, 1, 2, 1, 10, 15, 73, 4, 3), )
if mibBuilder.loadTexts: fddimibPATHConfigTable.setDescription('A table of Path configuration entries.  This \n                      table lists all the resources that may be in this \n                      Path.')
fddimibPATHConfigEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 15, 73, 4, 3, 1), ).setIndexNames((0, "FDDI-SMT73-MIB", "fddimibPATHConfigSMTIndex"), (0, "FDDI-SMT73-MIB", "fddimibPATHConfigPATHIndex"), (0, "FDDI-SMT73-MIB", "fddimibPATHConfigTokenOrder"))
if mibBuilder.loadTexts: fddimibPATHConfigEntry.setDescription('A collection of objects containing information \n                      for a given PATH Configuration entry.')
fddimibPATHConfigSMTIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 4, 3, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,65535))).setMaxAccess("readonly")
if mibBuilder.loadTexts: fddimibPATHConfigSMTIndex.setDescription('The value of the SMT index associated with this \n                      configuration entry.')
fddimibPATHConfigPATHIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 4, 3, 1, 2), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,65535))).setMaxAccess("readonly")
if mibBuilder.loadTexts: fddimibPATHConfigPATHIndex.setDescription('The value of the PATH resource index associated \n                      with this configuration entry.')
fddimibPATHConfigTokenOrder = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 4, 3, 1, 3), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,65535))).setMaxAccess("readonly")
if mibBuilder.loadTexts: fddimibPATHConfigTokenOrder.setDescription('An object associated with Token order for this \n                      entry.  Thus if the token passes resources a, b, c \n                      and d, in that order, then the value of this \n                      object for these resources would be 1, 2, 3 and 4 \n                      respectively.')
fddimibPATHConfigResourceType = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 4, 3, 1, 4), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(2, 4,))).clone(namedValues=NamedValues(("mac", 2), ("port", 4),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: fddimibPATHConfigResourceType.setDescription('The type of resource associated with this \n                      configuration entry.')
fddimibPATHConfigResourceIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 4, 3, 1, 5), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,65535))).setMaxAccess("readonly")
if mibBuilder.loadTexts: fddimibPATHConfigResourceIndex.setDescription('The value of the SMT resource index used to refer \n                      to the instance of this MAC or Port resource.')
fddimibPATHConfigCurrentPath = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 4, 3, 1, 6), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5, 6,))).clone(namedValues=NamedValues(("isolated", 1), ("local", 2), ("secondary", 3), ("primary", 4), ("concatenated", 5), ("thru", 6),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: fddimibPATHConfigCurrentPath.setDescription('The current insertion status for this resource on \n                      this Path.')
fddimibPORTNumber = MibScalar((1, 3, 6, 1, 2, 1, 10, 15, 73, 5, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,65535))).setMaxAccess("readonly")
if mibBuilder.loadTexts: fddimibPORTNumber.setDescription("The total number of PORT implementations (across \n                      all SMTs) on this network management application \n                      entity.  The value for this variable must remain \n                      constant at least from one re-initialization of \n                      the entity's network management system to the next \n                      re-initialization.")
fddimibPORTTable = MibTable((1, 3, 6, 1, 2, 1, 10, 15, 73, 5, 2), )
if mibBuilder.loadTexts: fddimibPORTTable.setDescription('A list of PORT entries.  The number of entries \n                      shall not exceed the value of fddimibPORTNumber.')
fddimibPORTEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 15, 73, 5, 2, 1), ).setIndexNames((0, "FDDI-SMT73-MIB", "fddimibPORTSMTIndex"), (0, "FDDI-SMT73-MIB", "fddimibPORTIndex"))
if mibBuilder.loadTexts: fddimibPORTEntry.setDescription('A PORT entry containing information common to a \n                      given PORT.')
fddimibPORTSMTIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 5, 2, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,65535))).setMaxAccess("readonly")
if mibBuilder.loadTexts: fddimibPORTSMTIndex.setDescription('The value of the SMT index associated with this \n                      PORT.')
fddimibPORTIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 5, 2, 1, 2), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,65535))).setMaxAccess("readonly")
if mibBuilder.loadTexts: fddimibPORTIndex.setDescription("A unique value for each PORT within a given SMT, \n                      which is the same as the corresponding resource \n                      index in SMT.  The value for each PORT must remain \n                      constant at least from one re-initialization of \n                      the entity's network management system to the next \n                      re-initialization.")
fddimibPORTMyType = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 5, 2, 1, 3), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5,))).clone(namedValues=NamedValues(("a", 1), ("b", 2), ("s", 3), ("m", 4), ("none", 5),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: fddimibPORTMyType.setDescription("The value of the PORT's PC_Type (refer to ANSI \n                      9.4.1, and 9.6.3.2).")
fddimibPORTNeighborType = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 5, 2, 1, 4), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5,))).clone(namedValues=NamedValues(("a", 1), ("b", 2), ("s", 3), ("m", 4), ("none", 5),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: fddimibPORTNeighborType.setDescription('The type of the remote PORT as determined in PCM. \n                      This variable has an initial value of none, and is \n                      only modified in PC_RCode(3)_Actions (refer to \n                      ANSI SMT 9.6.3.2).')
fddimibPORTConnectionPolicies = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 5, 2, 1, 5), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,3))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: fddimibPORTConnectionPolicies.setDescription("A value representing the PORT's connection \n                      policies desired in the node. The value of pc- \n                      mac-lct is a term used in the PC_MAC_LCT Flag (see \n                      9.4.3.2).  The value of pc-mac-loop is a term used \n                      in the PC_MAC_Loop Flag. \n \n                      The value is a sum.  This value initially takes \n                      the value zero, then for each PORT policy, 2 \n                      raised to a power is added to the sum.  The powers \n                      are according to the following table: \n \n                                    Policy   Power \n                                pc-mac-lct     0 \n                               pc-mac-loop     1 ")
fddimibPORTMACIndicated = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 5, 2, 1, 6), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4,))).clone(namedValues=NamedValues(("tVal9FalseRVal9False", 1), ("tVal9FalseRVal9True", 2), ("tVal9TrueRVal9False", 3), ("tVal9TrueRVal9True", 4),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: fddimibPORTMACIndicated.setDescription('The indications (T_Val(9), R_Val(9)) in PC- \n                      Signalling, of the intent to place a MAC in the \n                      output token path to a PORT (refer to ANSI SMT \n                      9.6.3.2.).')
fddimibPORTCurrentPath = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 5, 2, 1, 7), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5, 6,))).clone(namedValues=NamedValues(("ce0", 1), ("ce1", 2), ("ce2", 3), ("ce3", 4), ("ce4", 5), ("ce5", 6),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: fddimibPORTCurrentPath.setDescription('Indicates the Path(s) into which this PORT is \n                      currently inserted.')
fddimibPORTRequestedPaths = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 5, 2, 1, 8), OctetString().subtype(subtypeSpec=ValueSizeConstraint(3,3)).setFixedLength(3)).setMaxAccess("readwrite")
if mibBuilder.loadTexts: fddimibPORTRequestedPaths.setDescription("This variable is a list of permitted Paths where \n                      each list element defines the Port's permitted \n                      Paths.  The first octet corresponds to 'none', the \n                      second octet to 'tree', and the third octet to \n                      'peer'.")
fddimibPORTMACPlacement = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 5, 2, 1, 9), FddiResourceId()).setMaxAccess("readonly")
if mibBuilder.loadTexts: fddimibPORTMACPlacement.setDescription('Indicates the MAC, if any, whose transmit path \n                      exits the station via this PORT. The value shall \n                      be zero if there is no MAC associated with the \n                      PORT. Otherwise, the MACIndex of the MAC will be \n                      the value of the variable.')
fddimibPORTAvailablePaths = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 5, 2, 1, 10), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,7))).setMaxAccess("readonly")
if mibBuilder.loadTexts: fddimibPORTAvailablePaths.setDescription('Indicates the Paths which are available to this \n                      Port. In the absence of faults, the A and B Ports \n                      will always have both the Primary and Secondary \n                      Paths available. \n \n                      The value is a sum.  This value initially takes \n                      the value zero, then for each type of PATH that \n                      this port has available, 2 raised to a power is \n                      added to the sum.  The powers are according to the \n                      following table: \n \n                               Path   Power \n                            Primary     0 \n                          Secondary     1 \n                              Local     2 ')
fddimibPORTPMDClass = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 5, 2, 1, 11), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5, 6, 7, 8,))).clone(namedValues=NamedValues(("multimode", 1), ("single-mode1", 2), ("single-mode2", 3), ("sonet", 4), ("low-cost-fiber", 5), ("twisted-pair", 6), ("unknown", 7), ("unspecified", 8),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: fddimibPORTPMDClass.setDescription('This variable indicates the type of PMD entity \n                      associated with this port.')
fddimibPORTConnectionCapabilities = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 5, 2, 1, 12), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,3))).setMaxAccess("readonly")
if mibBuilder.loadTexts: fddimibPORTConnectionCapabilities.setDescription('A value that indicates the connection \n                      capabilities of the port. The pc-mac-lct bit \n                      indicates that the station has the capability of \n                      setting the PC_MAC_LCT Flag. The pc-mac-loop bit \n                      indicates that the station has the capability of \n                      setting the PC_MAC_Loop Flag (refer to ANSI \n                      9.4.3.2). \n \n                      The value is a sum.  This value initially takes \n                      the value zero, then for each capability that this \n                      port has, 2 raised to a power is added to the sum. \n                      The powers are according to the following table: \n \n                         capability   Power \n                         pc-mac-lct     0 \n                        pc-mac-loop     1 ')
fddimibPORTBSFlag = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 5, 2, 1, 13), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("true", 1), ("false", 2),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: fddimibPORTBSFlag.setDescription('This variable assumes the value of the BS_Flag \n                      (refer to ANSI SMT 9.4.3.3).')
fddimibPORTLCTFailCts = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 5, 2, 1, 14), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: fddimibPORTLCTFailCts.setDescription('The count of the consecutive times the link \n                      confidence test (LCT) has failed during connection \n                      management (refer to ANSI 9.4.1).')
fddimibPORTLerEstimate = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 5, 2, 1, 15), Integer32().subtype(subtypeSpec=ValueRangeConstraint(4,15))).setMaxAccess("readonly")
if mibBuilder.loadTexts: fddimibPORTLerEstimate.setDescription('A long term average link error rate. It ranges \n                      from 10**-4 to 10**-15 and is reported as the \n                      absolute value of the base 10 logarithm (refer to \n                      ANSI SMT 9.4.7.5.).')
fddimibPORTLemRejectCts = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 5, 2, 1, 16), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: fddimibPORTLemRejectCts.setDescription('A link error monitoring count of the times that a \n                      link has been rejected.')
fddimibPORTLemCts = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 5, 2, 1, 17), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: fddimibPORTLemCts.setDescription('The aggregate link error monitor error count, set \n                      to zero only on station initialization.')
fddimibPORTLerCutoff = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 5, 2, 1, 18), Integer32().subtype(subtypeSpec=ValueRangeConstraint(4,15))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: fddimibPORTLerCutoff.setDescription('The link error rate estimate at which a link \n                      connection will be broken. It ranges from 10**-4 \n                      to 10**-15 and is reported as the absolute value \n                      of the base 10 logarithm (default of 7).')
fddimibPORTLerAlarm = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 5, 2, 1, 19), Integer32().subtype(subtypeSpec=ValueRangeConstraint(4,15))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: fddimibPORTLerAlarm.setDescription('The link error rate estimate at which a link \n                      connection will generate an alarm. It ranges from \n                      10**-4 to 10**-15 and is reported as the absolute \n                      value of the base 10 logarithm of the estimate \n                      (default of 8).')
fddimibPORTConnectState = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 5, 2, 1, 20), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4,))).clone(namedValues=NamedValues(("disabled", 1), ("connecting", 2), ("standby", 3), ("active", 4),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: fddimibPORTConnectState.setDescription('An indication of the connect state of this PORT \n                      and is equal to the value of Connect_State (refer \n                      to ANSI 9.4.1)')
fddimibPORTPCMState = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 5, 2, 1, 21), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5, 6, 7, 8, 9, 10,))).clone(namedValues=NamedValues(("pc0", 1), ("pc1", 2), ("pc2", 3), ("pc3", 4), ("pc4", 5), ("pc5", 6), ("pc6", 7), ("pc7", 8), ("pc8", 9), ("pc9", 10),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: fddimibPORTPCMState.setDescription("The state of this Port's PCM state machine refer \n                      to ANSI SMT 9.6.2).")
fddimibPORTPCWithhold = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 5, 2, 1, 22), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4,))).clone(namedValues=NamedValues(("none", 1), ("m-m", 2), ("otherincompatible", 3), ("pathnotavailable", 4),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: fddimibPORTPCWithhold.setDescription('The value of PC_Withhold (refer to ANSI SMT \n                      9.4.1).')
fddimibPORTLerFlag = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 5, 2, 1, 23), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("true", 1), ("false", 2),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: fddimibPORTLerFlag.setDescription('The condition becomes active when the value of \n                      fddiPORTLerEstimate is less than or equal to \n                      fddiPORTLerAlarm. This will be reported with the \n                      Status Report Frames (SRF) (refer to ANSI SMT \n                       7.2.7 and 8.3).')
fddimibPORTHardwarePresent = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 5, 2, 1, 24), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("true", 1), ("false", 2),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: fddimibPORTHardwarePresent.setDescription('This variable indicates the presence of \n                      underlying hardware support for this Port object. \n                      If the value of this object is false(2), the \n                      reporting of the objects in this entry may be \n                      handled in an implementation-specific manner.')
fddimibPORTAction = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 15, 73, 5, 2, 1, 25), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5, 6,))).clone(namedValues=NamedValues(("other", 1), ("maintPORT", 2), ("enablePORT", 3), ("disablePORT", 4), ("startPORT", 5), ("stopPORT", 6),))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: fddimibPORTAction.setDescription("Causes a Control signal to be generated with a \n                      control_action of 'Signal' and the 'variable' \n                      parameter set with the appropriate value (i.e., \n                      PC_Maint, PC_Enable, PC_Disable, PC_Start, or \n                      PC_Stop) (refer to ANSI 9.4.2).")
mibBuilder.exportSymbols("FDDI-SMT73-MIB", fddimibPATHConfigSMTIndex=fddimibPATHConfigSMTIndex, fddimibMACAvailablePaths=fddimibMACAvailablePaths, fddimibSMTTransitionTimeStamp=fddimibSMTTransitionTimeStamp, fddimibPORTHardwarePresent=fddimibPORTHardwarePresent, fddimibMACRequestedPaths=fddimibMACRequestedPaths, fddimibPATHConfigTable=fddimibPATHConfigTable, fddimibMACMAUnitdataAvailable=fddimibMACMAUnitdataAvailable, fddimibMACFrameStatusFunctions=fddimibMACFrameStatusFunctions, fddimibSMTConfigCapabilities=fddimibSMTConfigCapabilities, fddimibMACNumber=fddimibMACNumber, fddimibMACSMTIndex=fddimibMACSMTIndex, fddimibSMTECMState=fddimibSMTECMState, FddiResourceId=FddiResourceId, fddimibPATHSMTIndex=fddimibPATHSMTIndex, fddimibMACTMaxCapability=fddimibMACTMaxCapability, fddimibMAC=fddimibMAC, fddimibPORTLemRejectCts=fddimibPORTLemRejectCts, fddimibMACSMTAddress=fddimibMACSMTAddress, fddimibMACRMTState=fddimibMACRMTState, fddimibPORTEntry=fddimibPORTEntry, fddimibSMTTNotify=fddimibSMTTNotify, fddimibPORTLerAlarm=fddimibPORTLerAlarm, FddiTimeNano=FddiTimeNano, fddimibMACFrameErrorRatio=fddimibMACFrameErrorRatio, fddimibPORTSMTIndex=fddimibPORTSMTIndex, fddimibSMTStationAction=fddimibSMTStationAction, fddimibMACCopiedCts=fddimibMACCopiedCts, fddimibSMTNumber=fddimibSMTNumber, fddimib=fddimib, FddiMACLongAddressType=FddiMACLongAddressType, fddimibSMTLoVersionId=fddimibSMTLoVersionId, fddimibMACTransmitCts=fddimibMACTransmitCts, fddimibMACHardwarePresent=fddimibMACHardwarePresent, fddimibSMTBypassPresent=fddimibSMTBypassPresent, fddimibPORTIndex=fddimibPORTIndex, fddimibSMTTable=fddimibSMTTable, fddimibMACDownstreamNbr=fddimibMACDownstreamNbr, fddimibSMTOpVersionId=fddimibSMTOpVersionId, fddimibPORTConnectionCapabilities=fddimibPORTConnectionCapabilities, fddimibPATHConfigResourceIndex=fddimibPATHConfigResourceIndex, fddimibPORTCurrentPath=fddimibPORTCurrentPath, fddimibMACIndex=fddimibMACIndex, fddimibMACOldDownstreamNbr=fddimibMACOldDownstreamNbr, fddimibSMTTraceMaxExpiration=fddimibSMTTraceMaxExpiration, fddimibPORTPCWithhold=fddimibPORTPCWithhold, fddimibPORTTable=fddimibPORTTable, fddimibMACNotCopiedFlag=fddimibMACNotCopiedFlag, FddiSMTStationIdType=FddiSMTStationIdType, fddimibMACTvxValue=fddimibMACTvxValue, fddimibSMTRemoteDisconnectFlag=fddimibSMTRemoteDisconnectFlag, fddimibMACTokenCts=fddimibMACTokenCts, fddimibMACCountersTable=fddimibMACCountersTable, fddimibPORTNumber=fddimibPORTNumber, fddimibMACNotCopiedCts=fddimibMACNotCopiedCts, fddimibPORTConnectState=fddimibPORTConnectState, fddimibPORTAction=fddimibPORTAction, fddimibSMTStationStatus=fddimibSMTStationStatus, fddimibPORTNeighborType=fddimibPORTNeighborType, fddimibPORTLerEstimate=fddimibPORTLerEstimate, fddimibPORTPMDClass=fddimibPORTPMDClass, fddimibMACTVXCapability=fddimibMACTVXCapability, FddiTimeMilli=FddiTimeMilli, fddimibPATHTVXLowerBound=fddimibPATHTVXLowerBound, fddimibSMTHiVersionId=fddimibSMTHiVersionId, fddimibMACTReq=fddimibMACTReq, fddimibPATHNumber=fddimibPATHNumber, fddimibSMTUserData=fddimibSMTUserData, fddimibMACFrameCts=fddimibMACFrameCts, fddimibPATHConfigTokenOrder=fddimibPATHConfigTokenOrder, transmission=transmission, fddimibMACLostCts=fddimibMACLostCts, fddimibMACFrameErrorThreshold=fddimibMACFrameErrorThreshold, fddimibSMTConnectionPolicy=fddimibSMTConnectionPolicy, fddimibMACErrorCts=fddimibMACErrorCts, fddimibPORT=fddimibPORT, fddimibPORTLCTFailCts=fddimibPORTLCTFailCts, fddi=fddi, fddimibPORTMACPlacement=fddimibPORTMACPlacement, fddimibSMTEntry=fddimibSMTEntry, fddimibPORTLerFlag=fddimibPORTLerFlag, fddimibPORTLemCts=fddimibPORTLemCts, fddimibMACIfIndex=fddimibMACIfIndex, fddimibSMTCFState=fddimibSMTCFState, fddimibPATHConfigEntry=fddimibPATHConfigEntry, fddimibPORTAvailablePaths=fddimibPORTAvailablePaths, fddimibPATHTMaxLowerBound=fddimibPATHTMaxLowerBound, fddimibPORTMyType=fddimibPORTMyType, fddimibMACTvxExpiredCts=fddimibMACTvxExpiredCts, fddimibPATHConfigCurrentPath=fddimibPATHConfigCurrentPath, fddimibSMTIndex=fddimibSMTIndex, fddimibPATHConfigResourceType=fddimibPATHConfigResourceType, fddimibSMTPeerWrapFlag=fddimibSMTPeerWrapFlag, fddimibSMTStationId=fddimibSMTStationId, fddimibPATH=fddimibPATH, fddimibMACDownstreamPORTType=fddimibMACDownstreamPORTType, fddimibMACOldUpstreamNbr=fddimibMACOldUpstreamNbr, fddimibPORTRequestedPaths=fddimibPORTRequestedPaths, fddimibSMT=fddimibSMT, fddimibMACFrameErrorFlag=fddimibMACFrameErrorFlag, fddimibPATHConfigPATHIndex=fddimibPATHConfigPATHIndex, fddimibPATHMaxTReq=fddimibPATHMaxTReq, fddimibMACUnaDaFlag=fddimibMACUnaDaFlag, fddimibPORTBSFlag=fddimibPORTBSFlag, fddimibPORTConnectionPolicies=fddimibPORTConnectionPolicies, fddimibMACCurrentPath=fddimibMACCurrentPath, fddimibMACRingOpCts=fddimibMACRingOpCts, fddimibSMTMACCts=fddimibSMTMACCts, fddimibSMTTimeStamp=fddimibSMTTimeStamp, fddimibMACNotCopiedRatio=fddimibMACNotCopiedRatio, fddimibMACDupAddressTest=fddimibMACDupAddressTest, fddimibPORTLerCutoff=fddimibPORTLerCutoff, fddimibSMTConfigPolicy=fddimibSMTConfigPolicy, fddimibMACTMax=fddimibMACTMax, fddimibPATHIndex=fddimibPATHIndex, fddimibMACLateCts=fddimibMACLateCts, fddimibSMTNonMasterCts=fddimibSMTNonMasterCts, fddimibMACCountersEntry=fddimibMACCountersEntry, fddimibMACUpstreamNbr=fddimibMACUpstreamNbr, fddimibPATHEntry=fddimibPATHEntry, fddimibPATHTable=fddimibPATHTable, fddimibMACMAUnitdataEnable=fddimibMACMAUnitdataEnable, fddimibPORTPCMState=fddimibPORTPCMState, fddimibMACTNeg=fddimibMACTNeg, fddimibSMTMIBVersionId=fddimibSMTMIBVersionId, fddimibSMTMasterCts=fddimibSMTMasterCts, fddimibSMTStatRptPolicy=fddimibSMTStatRptPolicy, fddimibPORTMACIndicated=fddimibPORTMACIndicated, fddimibMACNotCopiedThreshold=fddimibMACNotCopiedThreshold, fddimibMACCounters=fddimibMACCounters, fddimibSMTAvailablePaths=fddimibSMTAvailablePaths, fddimibMACEntry=fddimibMACEntry, fddimibMACDaFlag=fddimibMACDaFlag, fddimibMACTable=fddimibMACTable)



#
# PySNMP MIB module DISMAN-EXPRESSION-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/DISMAN-EXPRESSION-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:07:59 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( ObjectIdentifier, Integer, OctetString, ) = mibBuilder.importSymbols("ASN1", "ObjectIdentifier", "Integer", "OctetString")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ConstraintsUnion, ValueSizeConstraint, ConstraintsIntersection, SingleValueConstraint, ValueRangeConstraint, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ConstraintsUnion", "ValueSizeConstraint", "ConstraintsIntersection", "SingleValueConstraint", "ValueRangeConstraint")
( SnmpAdminString, ) = mibBuilder.importSymbols("SNMP-FRAMEWORK-MIB", "SnmpAdminString")
( ModuleCompliance, NotificationGroup, ObjectGroup, ) = mibBuilder.importSymbols("SNMPv2-CONF", "ModuleCompliance", "NotificationGroup", "ObjectGroup")
( sysUpTime, ) = mibBuilder.importSymbols("SNMPv2-MIB", "sysUpTime")
( Gauge32, Bits, Unsigned32, Counter64, ObjectIdentity, zeroDotZero, TimeTicks, ModuleIdentity, Integer32, IpAddress, Counter32, mib_2, iso, NotificationType, MibIdentifier, MibScalar, MibTable, MibTableRow, MibTableColumn, ) = mibBuilder.importSymbols("SNMPv2-SMI", "Gauge32", "Bits", "Unsigned32", "Counter64", "ObjectIdentity", "zeroDotZero", "TimeTicks", "ModuleIdentity", "Integer32", "IpAddress", "Counter32", "mib-2", "iso", "NotificationType", "MibIdentifier", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn")
( DisplayString, TruthValue, TimeStamp, TextualConvention, RowStatus, ) = mibBuilder.importSymbols("SNMPv2-TC", "DisplayString", "TruthValue", "TimeStamp", "TextualConvention", "RowStatus")
dismanExpressionMIB = ModuleIdentity((1, 3, 6, 1, 2, 1, 90)).setRevisions(("2000-10-16 00:00",))
if mibBuilder.loadTexts: dismanExpressionMIB.setLastUpdated('200010160000Z')
if mibBuilder.loadTexts: dismanExpressionMIB.setOrganization('IETF Distributed Management Working Group')
if mibBuilder.loadTexts: dismanExpressionMIB.setContactInfo('Ramanathan Kavasseri\n                  Cisco Systems, Inc.\n                  170 West Tasman Drive,\n                  San Jose CA 95134-1706.\n                  Phone: +1 408 527 2446\n                  Email: ramk@cisco.com')
if mibBuilder.loadTexts: dismanExpressionMIB.setDescription('The MIB module for defining expressions of MIB objects for\n     management purposes.')
dismanExpressionMIBObjects = MibIdentifier((1, 3, 6, 1, 2, 1, 90, 1))
expResource = MibIdentifier((1, 3, 6, 1, 2, 1, 90, 1, 1))
expDefine = MibIdentifier((1, 3, 6, 1, 2, 1, 90, 1, 2))
expValue = MibIdentifier((1, 3, 6, 1, 2, 1, 90, 1, 3))
expResourceDeltaMinimum = MibScalar((1, 3, 6, 1, 2, 1, 90, 1, 1, 1), Integer32().subtype(subtypeSpec=ConstraintsUnion(ValueRangeConstraint(-1,-1),ValueRangeConstraint(1,600),))).setUnits('seconds').setMaxAccess("readwrite")
if mibBuilder.loadTexts: expResourceDeltaMinimum.setDescription("The minimum expExpressionDeltaInterval this system will\n     accept.  A system may use the larger values of this minimum to\n     lessen the impact of constantly computing deltas.  For larger\n     delta sampling intervals the system samples less often and\n     suffers less overhead.  This object provides a way to enforce\n     such lower overhead for all expressions created after it is\n     set.\n\n     The value -1 indicates that expResourceDeltaMinimum is\n     irrelevant as the system will not accept 'deltaValue' as a\n     value for expObjectSampleType.\n\n     Unless explicitly resource limited, a system's value for\n     this object should be 1, allowing as small as a 1 second\n     interval for ongoing delta sampling.\n\n     Changing this value will not invalidate an existing setting\n     of expObjectSampleType.")
expResourceDeltaWildcardInstanceMaximum = MibScalar((1, 3, 6, 1, 2, 1, 90, 1, 1, 2), Unsigned32()).setUnits('instances').setMaxAccess("readwrite")
if mibBuilder.loadTexts: expResourceDeltaWildcardInstanceMaximum.setDescription("For every instance of a deltaValue object, one dynamic instance\n     entry is needed for holding the instance value from the previous\n     sample, i.e. to maintain state.\n\n     This object limits maximum number of dynamic instance entries\n     this system will support for wildcarded delta objects in\n     expressions. For a given delta expression, the number of\n     dynamic instances is the number of values that meet all criteria\n     to exist times the number of delta values in the expression.\n\n     A value of 0 indicates no preset limit, that is, the limit\n     is dynamic based on system operation and resources.\n\n     Unless explicitly resource limited, a system's value for\n     this object should be 0.\n\n\n     Changing this value will not eliminate or inhibit existing delta\n     wildcard instance objects but will prevent the creation of more\n     such objects.\n\n     An attempt to allocate beyond the limit results in expErrorCode\n     being tooManyWildcardValues for that evaluation attempt.")
expResourceDeltaWildcardInstances = MibScalar((1, 3, 6, 1, 2, 1, 90, 1, 1, 3), Gauge32()).setUnits('instances').setMaxAccess("readonly")
if mibBuilder.loadTexts: expResourceDeltaWildcardInstances.setDescription('The number of currently active instance entries as\n     defined for expResourceDeltaWildcardInstanceMaximum.')
expResourceDeltaWildcardInstancesHigh = MibScalar((1, 3, 6, 1, 2, 1, 90, 1, 1, 4), Gauge32()).setUnits('instances').setMaxAccess("readonly")
if mibBuilder.loadTexts: expResourceDeltaWildcardInstancesHigh.setDescription('The highest value of expResourceDeltaWildcardInstances\n     that has occurred since initialization of the managed\n     system.')
expResourceDeltaWildcardInstanceResourceLacks = MibScalar((1, 3, 6, 1, 2, 1, 90, 1, 1, 5), Counter32()).setUnits('instances').setMaxAccess("readonly")
if mibBuilder.loadTexts: expResourceDeltaWildcardInstanceResourceLacks.setDescription('The number of times this system could not evaluate an\n     expression because that would have created a value instance in\n     excess of expResourceDeltaWildcardInstanceMaximum.')
expExpressionTable = MibTable((1, 3, 6, 1, 2, 1, 90, 1, 2, 1), )
if mibBuilder.loadTexts: expExpressionTable.setDescription('A table of expression definitions.')
expExpressionEntry = MibTableRow((1, 3, 6, 1, 2, 1, 90, 1, 2, 1, 1), ).setIndexNames((0, "DISMAN-EXPRESSION-MIB", "expExpressionOwner"), (0, "DISMAN-EXPRESSION-MIB", "expExpressionName"))
if mibBuilder.loadTexts: expExpressionEntry.setDescription("Information about a single expression.  New expressions\n     can be created using expExpressionRowStatus.\n\n     To create an expression first create the named entry in this\n     table.  Then use expExpressionName to populate expObjectTable.\n     For expression evaluation to succeed all related entries in\n     expExpressionTable and expObjectTable must be 'active'.  If\n     these conditions are not met the corresponding values in\n     expValue simply are not instantiated.\n\n     Deleting an entry deletes all related entries in expObjectTable\n     and expErrorTable.\n\n     Because of the relationships among the multiple tables for an\n     expression (expExpressionTable, expObjectTable, and\n     expValueTable) and the SNMP rules for independence in setting\n     object values, it is necessary to do final error checking when\n     an expression is evaluated, that is, when one of its instances\n     in expValueTable is read or a delta interval expires.  Earlier\n     checking need not be done and an implementation may not impose\n     any ordering on the creation of objects related to an\n     expression.\n\n     To maintain security of MIB information, when creating a new row in\n     this table, the managed system must record the security credentials\n     of the requester.  These security credentials are the parameters\n     necessary as inputs to isAccessAllowed from the Architecture for\n\n     Describing SNMP Management Frameworks.  When obtaining the objects\n     that make up the expression, the system must (conceptually) use\n     isAccessAllowed to ensure that it does not violate security.\n\n     The evaluation of the expression takes place under the\n     security credentials of the creator of its expExpressionEntry.\n\n     Values of read-write objects in this table may be changed\n\n     at any time.")
expExpressionOwner = MibTableColumn((1, 3, 6, 1, 2, 1, 90, 1, 2, 1, 1, 1), SnmpAdminString().subtype(subtypeSpec=ValueSizeConstraint(0,32)))
if mibBuilder.loadTexts: expExpressionOwner.setDescription('The owner of this entry. The exact semantics of this\n     string are subject to the security policy defined by the\n     security administrator.')
expExpressionName = MibTableColumn((1, 3, 6, 1, 2, 1, 90, 1, 2, 1, 1, 2), SnmpAdminString().subtype(subtypeSpec=ValueSizeConstraint(1,32)))
if mibBuilder.loadTexts: expExpressionName.setDescription('The name of the expression.  This is locally unique, within\n     the scope of an expExpressionOwner.')
expExpression = MibTableColumn((1, 3, 6, 1, 2, 1, 90, 1, 2, 1, 1, 3), OctetString().subtype(subtypeSpec=ValueSizeConstraint(1,1024))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: expExpression.setDescription("The expression to be evaluated.  This object is the same\n     as a DisplayString (RFC 1903) except for its maximum length.\n\n     Except for the variable names the expression is in ANSI C\n     syntax.  Only the subset of ANSI C operators and functions\n     listed here is allowed.\n\n     Variables are expressed as a dollar sign ('$') and an\n\n     integer that corresponds to an expObjectIndex.  An\n     example of a valid expression is:\n\n          ($1-$5)*100\n\n     Expressions must not be recursive, that is although an expression\n     may use the results of another expression, it must not contain\n     any variable that is directly or indirectly a result of its own\n     evaluation. The managed system must check for recursive\n     expressions.\n\n     The only allowed operators are:\n\n          ( )\n          - (unary)\n          + - * / %\n          & | ^ << >> ~\n          ! && || == != > >= < <=\n\n     Note the parentheses are included for parenthesizing the\n     expression, not for casting data types.\n\n     The only constant types defined are:\n\n          int (32-bit signed)\n          long (64-bit signed)\n          unsigned int\n          unsigned long\n          hexadecimal\n          character\n          string\n          oid\n\n     The default type for a positive integer is int unless it is too\n     large in which case it is long.\n\n     All but oid are as defined for ANSI C.  Note that a\n     hexadecimal constant may end up as a scalar or an array of\n     8-bit integers.  A string constant is enclosed in double\n     quotes and may contain back-slashed individual characters\n     as in ANSI C.\n\n     An oid constant comprises 32-bit, unsigned integers and at\n     least one period, for example:\n\n          0.\n          .0\n          1.3.6.1\n\n     No additional leading or trailing subidentifiers are automatically\n     added to an OID constant.  The constant is taken as expressed.\n\n     Integer-typed objects are treated as 32- or 64-bit, signed\n     or unsigned integers, as appropriate.  The results of\n     mixing them are as for ANSI C, including the type of the\n     result.  Note that a 32-bit value is thus promoted to 64 bits\n     only in an operation with a 64-bit value.  There is no\n     provision for larger values to handle overflow.\n\n     Relative to SNMP data types, a resulting value becomes\n     unsigned when calculating it uses any unsigned value,\n     including a counter.  To force the final value to be of\n     data type counter the expression must explicitly use the\n     counter32() or counter64() function (defined below).\n\n     OCTET STRINGS and OBJECT IDENTIFIERs are treated as\n     one-dimensioned arrays of unsigned 8-bit integers and\n     unsigned 32-bit integers, respectively.\n\n     IpAddresses are treated as 32-bit, unsigned integers in\n     network byte order, that is, the hex version of 255.0.0.0 is\n     0xff000000.\n\n     Conditional expressions result in a 32-bit, unsigned integer\n     of value 0 for false or 1 for true. When an arbitrary value\n     is used as a boolean 0 is false and non-zero is true.\n\n     Rules for the resulting data type from an operation, based on\n     the operator:\n\n     For << and >> the result is the same as the left hand operand.\n\n     For &&, ||, ==, !=, <, <=, >, and >= the result is always\n     Unsigned32.\n\n     For unary - the result is always Integer32.\n\n     For +, -, *, /, %, &, |, and ^ the result is promoted according\n     to the following rules, in order from most to least preferred:\n\n          If left hand and right hand operands are the same type,\n          use that.\n\n          If either side is Counter64, use that.\n\n          If either side is IpAddress, use that.\n\n\n          If either side is TimeTicks, use that.\n\n          If either side is Counter32, use that.\n\n          Otherwise use Unsigned32.\n\n     The following rules say what operators apply with what data\n     types.  Any combination not explicitly defined does not work.\n\n     For all operators any of the following can be the left hand or\n     right hand operand: Integer32, Counter32, Unsigned32, Counter64.\n\n     The operators +, -, *, /, %, <, <=, >, and >= work with\n     TimeTicks.\n\n     The operators &, |, and ^ work with IpAddress.\n\n     The operators << and >> work with IpAddress but only as the\n     left hand operand.\n\n     The + operator performs a concatenation of two OCTET STRINGs or\n     two OBJECT IDENTIFIERs.\n\n     The operators &, | perform bitwise operations on OCTET STRINGs.\n     If the OCTET STRING happens to be a DisplayString the results\n     may be meaningless, but the agent system does not check this as\n     some such systems do not have this information.\n\n     The operators << and >> perform bitwise operations on OCTET\n     STRINGs appearing as the left hand operand.\n\n     The only functions defined are:\n\n          counter32\n          counter64\n          arraySection\n          stringBegins\n          stringEnds\n          stringContains\n          oidBegins\n          oidEnds\n          oidContains\n          average\n          maximum\n          minimum\n          sum\n          exists\n\n\n     The following function definitions indicate their parameters by\n     naming the data type of the parameter in the parameter's position\n     in the parameter list.  The parameter must be of the type indicated\n     and generally may be a constant, a MIB object, a function, or an\n     expression.\n\n     counter32(integer) - wrapped around an integer value counter32\n     forces Counter32 as a data type.\n\n     counter64(integer) - similar to counter32 except that the\n     resulting data type is 'counter64'.\n\n     arraySection(array, integer, integer) - selects a piece of an\n     array (i.e. part of an OCTET STRING or OBJECT IDENTIFIER).  The\n     integer arguments are in the range 0 to 4,294,967,295.  The\n     first is an initial array index (one-dimensioned) and the second\n     is an ending array index.  A value of 0 indicates first or last\n     element, respectively.  If the first element is larger than the\n     array length the result is 0 length.  If the second integer is\n     less than or equal to the first, the result is 0 length.  If the\n     second is larger than the array length it indicates last\n     element.\n\n     stringBegins/Ends/Contains(octetString, octetString) - looks for\n     the second string (which can be a string constant) in the first\n     and returns the one-dimensioned arrayindex where the match began.\n     A return value of 0 indicates no match (i.e. boolean false).\n\n     oidBegins/Ends/Contains(oid, oid) - looks for the second OID\n     (which can be an OID constant) in the first and returns the\n     the one-dimensioned index where the match began. A return value\n     of 0 indicates no match (i.e. boolean false).\n\n     average/maximum/minimum(integer) - calculates the average,\n     minimum, or maximum value of the integer valued object over\n     multiple sample times.  If the object disappears for any\n     sample period, the accumulation and the resulting value object\n     cease to exist until the object reappears at which point the\n     calculation starts over.\n\n     sum(integerObject*) - sums all available values of the\n     wildcarded integer object, resulting in an integer scalar.  Must\n     be used with caution as it wraps on overflow with no\n     notification.\n\n     exists(anyTypeObject) - verifies the object instance exists. A\n     return value of 0 indicates NoSuchInstance (i.e. boolean\n     false).")
expExpressionValueType = MibTableColumn((1, 3, 6, 1, 2, 1, 90, 1, 2, 1, 1, 4), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5, 6, 7, 8,))).clone(namedValues=NamedValues(("counter32", 1), ("unsigned32", 2), ("timeTicks", 3), ("integer32", 4), ("ipAddress", 5), ("octetString", 6), ("objectId", 7), ("counter64", 8),)).clone('counter32')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: expExpressionValueType.setDescription('The type of the expression value.  One and only one of the\n     value objects in expValueTable will be instantiated to match\n     this type.\n\n     If the result of the expression can not be made into this type,\n     an invalidOperandType error will occur.')
expExpressionComment = MibTableColumn((1, 3, 6, 1, 2, 1, 90, 1, 2, 1, 1, 5), SnmpAdminString().clone(hexValue="")).setMaxAccess("readcreate")
if mibBuilder.loadTexts: expExpressionComment.setDescription('A comment to explain the use or meaning of the expression.')
expExpressionDeltaInterval = MibTableColumn((1, 3, 6, 1, 2, 1, 90, 1, 2, 1, 1, 6), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,86400))).setUnits('seconds').setMaxAccess("readcreate")
if mibBuilder.loadTexts: expExpressionDeltaInterval.setDescription("Sampling interval for objects in this expression with\n     expObjectSampleType 'deltaValue'.\n\n     This object has no effect if the the expression has no\n     deltaValue objects.\n\n     A value of 0 indicates no automated sampling.  In this case\n     the delta is the difference from the last time the expression\n     was evaluated.  Note that this is subject to unpredictable\n     delta times in the face of retries or multiple managers.\n\n     A value greater than zero is the number of seconds between\n     automated samples.\n\n     Until the delta interval has expired once the delta for the\n\n     object is effectively not instantiated and evaluating\n     the expression has results as if the object itself were not\n     instantiated.\n\n     Note that delta values potentially consume large amounts of\n     system CPU and memory.  Delta state and processing must\n     continue constantly even if the expression is not being used.\n     That is, the expression is being evaluated every delta interval,\n     even if no application is reading those values.  For wildcarded\n     objects this can be substantial overhead.\n\n     Note that delta intervals, external expression value sampling\n     intervals and delta intervals for expressions within other\n     expressions can have unusual interactions as they are impossible\n     to synchronize accurately.  In general one interval embedded\n     below another must be enough shorter that the higher sample\n     sees relatively smooth, predictable behavior.  So, for example,\n     to avoid the higher level getting the same sample twice, the\n     lower level should sample at least twice as fast as the higher\n     level does.")
expExpressionPrefix = MibTableColumn((1, 3, 6, 1, 2, 1, 90, 1, 2, 1, 1, 7), ObjectIdentifier()).setMaxAccess("readonly")
if mibBuilder.loadTexts: expExpressionPrefix.setDescription('An object prefix to assist an application in determining\n     the instance indexing to use in expValueTable, relieving the\n     application of the need to scan the expObjectTable to\n     determine such a prefix.\n\n     See expObjectTable for information on wildcarded objects.\n\n     If the expValueInstance portion of the value OID may\n     be treated as a scalar (that is, normally, 0) the value of\n     expExpressionPrefix is zero length, that is, no OID at all.\n     Note that zero length implies a null OID, not the OID 0.0.\n\n     Otherwise, the value of expExpressionPrefix is the expObjectID\n     value of any one of the wildcarded objects for the expression.\n     This is sufficient, as the remainder, that is, the instance\n     fragment relevant to instancing the values, must be the same for\n     all wildcarded objects in the expression.')
expExpressionErrors = MibTableColumn((1, 3, 6, 1, 2, 1, 90, 1, 2, 1, 1, 8), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: expExpressionErrors.setDescription('The number of errors encountered while evaluating this\n     expression.\n\n     Note that an object in the expression not being accessible,\n     is not considered an error. An example of an inaccessible\n     object is when the object is excluded from the view of the\n     user whose security credentials are used in the expression\n     evaluation. In such cases, it is a legitimate condition\n     that causes the corresponding expression value not to be\n     instantiated.')
expExpressionEntryStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 90, 1, 2, 1, 1, 9), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: expExpressionEntryStatus.setDescription('The control that allows creation and deletion of entries.')
expErrorTable = MibTable((1, 3, 6, 1, 2, 1, 90, 1, 2, 2), )
if mibBuilder.loadTexts: expErrorTable.setDescription('A table of expression errors.')
expErrorEntry = MibTableRow((1, 3, 6, 1, 2, 1, 90, 1, 2, 2, 1), ).setIndexNames((0, "DISMAN-EXPRESSION-MIB", "expExpressionOwner"), (0, "DISMAN-EXPRESSION-MIB", "expExpressionName"))
if mibBuilder.loadTexts: expErrorEntry.setDescription('Information about errors in processing an expression.\n\n     Entries appear in this table only when there is a matching\n     expExpressionEntry and then only when there has been an\n     error for that expression as reflected by the error codes\n     defined for expErrorCode.')
expErrorTime = MibTableColumn((1, 3, 6, 1, 2, 1, 90, 1, 2, 2, 1, 1), TimeStamp()).setMaxAccess("readonly")
if mibBuilder.loadTexts: expErrorTime.setDescription('The value of sysUpTime the last time an error caused a\n     failure to evaluate this expression.')
expErrorIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 90, 1, 2, 2, 1, 2), Integer32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: expErrorIndex.setDescription('The one-dimensioned character array index into\n     expExpression for where the error occurred.  The value\n     zero indicates irrelevance.')
expErrorCode = MibTableColumn((1, 3, 6, 1, 2, 1, 90, 1, 2, 2, 1, 3), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11,))).clone(namedValues=NamedValues(("invalidSyntax", 1), ("undefinedObjectIndex", 2), ("unrecognizedOperator", 3), ("unrecognizedFunction", 4), ("invalidOperandType", 5), ("unmatchedParenthesis", 6), ("tooManyWildcardValues", 7), ("recursion", 8), ("deltaTooShort", 9), ("resourceUnavailable", 10), ("divideByZero", 11),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: expErrorCode.setDescription("The error that occurred.  In the following explanations the\n     expected timing of the error is in parentheses.  'S' means\n     the error occurs on a Set request.  'E' means the error\n\n     occurs on the attempt to evaluate the expression either due to\n     Get from expValueTable or in ongoing delta processing.\n\n     invalidSyntax       the value sent for expExpression is not\n                    valid Expression MIB expression syntax\n                    (S)\n     undefinedObjectIndex     an object reference ($n) in\n                    expExpression does not have a matching\n                    instance in expObjectTable (E)\n     unrecognizedOperator     the value sent for expExpression held an\n                    unrecognized operator (S)\n     unrecognizedFunction     the value sent for expExpression held an\n                    unrecognized function name (S)\n     invalidOperandType  an operand in expExpression is not the\n                    right type for the associated operator\n                    or result (SE)\n     unmatchedParenthesis     the value sent for expExpression is not\n                    correctly parenthesized (S)\n     tooManyWildcardValues    evaluating the expression exceeded the\n                    limit set by\n                    expResourceDeltaWildcardInstanceMaximum\n                    (E)\n     recursion      through some chain of embedded\n                    expressions the expression invokes itself\n                    (E)\n     deltaTooShort       the delta for the next evaluation passed\n                    before the system could evaluate the\n                    present sample (E)\n     resourceUnavailable some resource, typically dynamic memory,\n                    was unavailable (SE)\n     divideByZero        an attempt to divide by zero occurred\n                    (E)\n\n     For the errors that occur when the attempt is made to set\n     expExpression Set request fails with the SNMP error code\n     'wrongValue'.  Such failures refer to the most recent failure to\n     Set expExpression, not to the present value of expExpression\n     which must be either unset or syntactically correct.\n\n     Errors that occur during evaluation for a Get* operation return\n     the SNMP error code 'genErr' except for 'tooManyWildcardValues'\n     and 'resourceUnavailable' which return the SNMP error code\n     'resourceUnavailable'.")
expErrorInstance = MibTableColumn((1, 3, 6, 1, 2, 1, 90, 1, 2, 2, 1, 4), ObjectIdentifier()).setMaxAccess("readonly")
if mibBuilder.loadTexts: expErrorInstance.setDescription('The expValueInstance being evaluated when the error\n     occurred.  A zero-length indicates irrelevance.')
expObjectTable = MibTable((1, 3, 6, 1, 2, 1, 90, 1, 2, 3), )
if mibBuilder.loadTexts: expObjectTable.setDescription('A table of object definitions for each expExpression.\n\n     Wildcarding instance IDs:\n\n     It is legal to omit all or part of the instance portion for\n     some or all of the objects in an expression. (See the\n     DESCRIPTION of expObjectID for details.  However, note that\n     if more than one object in the same expression is wildcarded\n     in this way, they all must be objects where that portion of\n     the instance is the same.  In other words, all objects may be\n     in the same SEQUENCE or in different SEQUENCEs but with the\n     same semantic index value (e.g., a value of ifIndex)\n     for the wildcarded portion.')
expObjectEntry = MibTableRow((1, 3, 6, 1, 2, 1, 90, 1, 2, 3, 1), ).setIndexNames((0, "DISMAN-EXPRESSION-MIB", "expExpressionOwner"), (0, "DISMAN-EXPRESSION-MIB", "expExpressionName"), (0, "DISMAN-EXPRESSION-MIB", "expObjectIndex"))
if mibBuilder.loadTexts: expObjectEntry.setDescription('Information about an object.  An application uses\n     expObjectEntryStatus to create entries in this table while\n     in the process of defining an expression.\n\n     Values of read-create objects in this table may be\n     changed at any time.')
expObjectIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 90, 1, 2, 3, 1, 1), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,4294967295)))
if mibBuilder.loadTexts: expObjectIndex.setDescription("Within an expression, a unique, numeric identification for an\n     object.  Prefixed with a dollar sign ('$') this is used to\n     reference the object in the corresponding expExpression.")
expObjectID = MibTableColumn((1, 3, 6, 1, 2, 1, 90, 1, 2, 3, 1, 2), ObjectIdentifier()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: expObjectID.setDescription('The OBJECT IDENTIFIER (OID) of this object.  The OID may be\n     fully qualified, meaning it includes a complete instance\n     identifier part (e.g., ifInOctets.1 or sysUpTime.0), or it\n     may not be fully qualified, meaning it may lack all or part\n     of the instance identifier.  If the expObjectID is not fully\n     qualified, then expObjectWildcard must be set to true(1).\n     The value of the expression will be multiple\n     values, as if done for a GetNext sweep of the object.\n\n     An object here may itself be the result of an expression but\n     recursion is not allowed.\n\n     NOTE:  The simplest implementations of this MIB may not allow\n     wildcards.')
expObjectIDWildcard = MibTableColumn((1, 3, 6, 1, 2, 1, 90, 1, 2, 3, 1, 3), TruthValue().clone('false')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: expObjectIDWildcard.setDescription('A true value indicates the expObjecID of this row is a wildcard\n        object. False indicates that expObjectID is fully instanced.\n        If all expObjectWildcard values for a given expression are FALSE,\n\n        expExpressionPrefix will reflect a scalar object (i.e. will\n        be 0.0).\n\n        NOTE:  The simplest implementations of this MIB may not allow\n        wildcards.')
expObjectSampleType = MibTableColumn((1, 3, 6, 1, 2, 1, 90, 1, 2, 3, 1, 4), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3,))).clone(namedValues=NamedValues(("absoluteValue", 1), ("deltaValue", 2), ("changedValue", 3),)).clone('absoluteValue')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: expObjectSampleType.setDescription("The method of sampling the selected variable.\n\n     An 'absoluteValue' is simply the present value of the object.\n\n     A 'deltaValue' is the present value minus the previous value,\n     which was sampled expExpressionDeltaInterval seconds ago.\n     This is intended primarily for use with SNMP counters, which are\n     meaningless as an 'absoluteValue', but may be used with any\n     integer-based value.\n\n     A 'changedValue' is a boolean for whether the present value is\n     different from the previous value.  It is applicable to any data\n     type and results in an Unsigned32 with value 1 if the object's\n     value is changed and 0 if not.  In all other respects it is as a\n     'deltaValue' and all statements and operation regarding delta\n     values apply to changed values.\n\n     When an expression contains both delta and absolute values\n     the absolute values are obtained at the end of the delta\n     period.")
sysUpTimeInstance = MibIdentifier((1, 3, 6, 1, 2, 1, 1, 3, 0))
expObjectDeltaDiscontinuityID = MibTableColumn((1, 3, 6, 1, 2, 1, 90, 1, 2, 3, 1, 5), ObjectIdentifier().clone((1, 3, 6, 1, 2, 1, 1, 3, 0))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: expObjectDeltaDiscontinuityID.setDescription("The OBJECT IDENTIFIER (OID) of a TimeTicks, TimeStamp, or\n     DateAndTime object that indicates a discontinuity in the value\n     at expObjectID.\n\n\n     This object is instantiated only if expObjectSampleType is\n     'deltaValue' or 'changedValue'.\n\n     The OID may be for a leaf object (e.g. sysUpTime.0) or may\n     be wildcarded to match expObjectID.\n\n     This object supports normal checking for a discontinuity in a\n     counter.  Note that if this object does not point to sysUpTime\n     discontinuity checking must still check sysUpTime for an overall\n     discontinuity.\n\n     If the object identified is not accessible no discontinuity\n     check will be made.")
expObjectDiscontinuityIDWildcard = MibTableColumn((1, 3, 6, 1, 2, 1, 90, 1, 2, 3, 1, 6), TruthValue().clone('false')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: expObjectDiscontinuityIDWildcard.setDescription("A true value indicates the expObjectDeltaDiscontinuityID of\n     this row is a wildcard object.  False indicates that\n     expObjectDeltaDiscontinuityID is fully instanced.\n\n     This object is instantiated only if expObjectSampleType is\n     'deltaValue' or 'changedValue'.\n\n     NOTE:  The simplest implementations of this MIB may not allow\n     wildcards.")
expObjectDiscontinuityIDType = MibTableColumn((1, 3, 6, 1, 2, 1, 90, 1, 2, 3, 1, 7), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3,))).clone(namedValues=NamedValues(("timeTicks", 1), ("timeStamp", 2), ("dateAndTime", 3),)).clone('timeTicks')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: expObjectDiscontinuityIDType.setDescription("The value 'timeTicks' indicates the expObjectDeltaDiscontinuityID\n     of this row is of syntax TimeTicks.  The value 'timeStamp' indicates\n     syntax TimeStamp.  The value 'dateAndTime indicates syntax\n     DateAndTime.\n\n     This object is instantiated only if expObjectSampleType is\n     'deltaValue' or 'changedValue'.")
expObjectConditional = MibTableColumn((1, 3, 6, 1, 2, 1, 90, 1, 2, 3, 1, 8), ObjectIdentifier().clone((0, 0))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: expObjectConditional.setDescription('The OBJECT IDENTIFIER (OID) of an object that overrides\n     whether the instance of expObjectID is to be considered\n     usable.  If the value of the object at expObjectConditional\n     is 0 or not instantiated, the object at expObjectID is\n     treated as if it is not instantiated.  In other words,\n     expObjectConditional is a filter that controls whether or\n     not to use the value at expObjectID.\n\n     The OID may be for a leaf object (e.g. sysObjectID.0) or may be\n     wildcarded to match expObjectID.  If expObject is wildcarded and\n     expObjectID in the same row is not, the wild portion of\n     expObjectConditional must match the wildcarding of the rest of\n     the expression.  If no object in the expression is wildcarded\n     but expObjectConditional is, use the lexically first instance\n     (if any) of expObjectConditional.\n\n     If the value of expObjectConditional is 0.0 operation is\n     as if the value pointed to by expObjectConditional is a\n     non-zero (true) value.\n\n     Note that expObjectConditional can not trivially use an object\n     of syntax TruthValue, since the underlying value is not 0 or 1.')
expObjectConditionalWildcard = MibTableColumn((1, 3, 6, 1, 2, 1, 90, 1, 2, 3, 1, 9), TruthValue().clone('false')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: expObjectConditionalWildcard.setDescription('A true value indicates the expObjectConditional of this row is\n     a wildcard object. False indicates that expObjectConditional is\n     fully instanced.\n\n     NOTE: The simplest implementations of this MIB may not allow\n     wildcards.')
expObjectEntryStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 90, 1, 2, 3, 1, 10), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: expObjectEntryStatus.setDescription('The control that allows creation/deletion of entries.\n\n     Objects in this table may be changed while\n     expObjectEntryStatus is in any state.')
expValueTable = MibTable((1, 3, 6, 1, 2, 1, 90, 1, 3, 1), )
if mibBuilder.loadTexts: expValueTable.setDescription('A table of values from evaluated expressions.')
expValueEntry = MibTableRow((1, 3, 6, 1, 2, 1, 90, 1, 3, 1, 1), ).setIndexNames((0, "DISMAN-EXPRESSION-MIB", "expExpressionOwner"), (0, "DISMAN-EXPRESSION-MIB", "expExpressionName"), (1, "DISMAN-EXPRESSION-MIB", "expValueInstance"))
if mibBuilder.loadTexts: expValueEntry.setDescription("A single value from an evaluated expression.  For a given\n     instance, only one 'Val' object in the conceptual row will be\n     instantiated, that is, the one with the appropriate type for\n     the value.  For values that contain no objects of\n     expObjectSampleType 'deltaValue' or 'changedValue', reading a\n     value from the table causes the evaluation of the expression\n     for that value.  For those that contain a 'deltaValue' or\n     'changedValue' the value read is as of the last sampling\n     interval.\n\n     If in the attempt to evaluate the expression one or more\n     of the necessary objects is not available, the corresponding\n     entry in this table is effectively not instantiated.\n\n     To maintain security of MIB information, when creating a new\n     row in this table, the managed system must record the security\n     credentials of the requester.  These security credentials are\n     the parameters necessary as inputs to isAccessAllowed from\n     [RFC2571]. When obtaining the objects that make up the\n     expression, the system must (conceptually) use isAccessAllowed to\n     ensure that it does not violate security.\n\n     The evaluation of that expression takes place under the\n\n     security credentials of the creator of its expExpressionEntry.\n\n     To maintain security of MIB information, expression evaluation must\n     take place using security credentials for the implied Gets of the\n     objects in the expression as inputs (conceptually) to\n     isAccessAllowed from the Architecture for Describing SNMP\n     Management Frameworks.  These are the security credentials of the\n     creator of the corresponding expExpressionEntry.")
expValueInstance = MibTableColumn((1, 3, 6, 1, 2, 1, 90, 1, 3, 1, 1, 1), ObjectIdentifier())
if mibBuilder.loadTexts: expValueInstance.setDescription("The final instance portion of a value's OID according to\n     the wildcarding in instances of expObjectID for the\n     expression.  The prefix of this OID fragment is 0.0,\n     leading to the following behavior.\n\n     If there is no wildcarding, the value is 0.0.0.  In other\n     words, there is one value which standing alone would have\n     been a scalar with a 0 at the end of its OID.\n\n     If there is wildcarding, the value is 0.0 followed by\n     a value that the wildcard can take, thus defining one value\n     instance for each real, possible value of the wildcard.\n     So, for example, if the wildcard worked out to be an ifIndex,\n     there is an expValueInstance for each applicable ifIndex.")
expValueCounter32Val = MibTableColumn((1, 3, 6, 1, 2, 1, 90, 1, 3, 1, 1, 2), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: expValueCounter32Val.setDescription("The value when expExpressionValueType is 'counter32'.")
expValueUnsigned32Val = MibTableColumn((1, 3, 6, 1, 2, 1, 90, 1, 3, 1, 1, 3), Unsigned32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: expValueUnsigned32Val.setDescription("The value when expExpressionValueType is 'unsigned32'.")
expValueTimeTicksVal = MibTableColumn((1, 3, 6, 1, 2, 1, 90, 1, 3, 1, 1, 4), TimeTicks()).setMaxAccess("readonly")
if mibBuilder.loadTexts: expValueTimeTicksVal.setDescription("The value when expExpressionValueType is 'timeTicks'.")
expValueInteger32Val = MibTableColumn((1, 3, 6, 1, 2, 1, 90, 1, 3, 1, 1, 5), Integer32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: expValueInteger32Val.setDescription("The value when expExpressionValueType is 'integer32'.")
expValueIpAddressVal = MibTableColumn((1, 3, 6, 1, 2, 1, 90, 1, 3, 1, 1, 6), IpAddress()).setMaxAccess("readonly")
if mibBuilder.loadTexts: expValueIpAddressVal.setDescription("The value when expExpressionValueType is 'ipAddress'.")
expValueOctetStringVal = MibTableColumn((1, 3, 6, 1, 2, 1, 90, 1, 3, 1, 1, 7), OctetString().subtype(subtypeSpec=ValueSizeConstraint(0,65536))).setMaxAccess("readonly")
if mibBuilder.loadTexts: expValueOctetStringVal.setDescription("The value when expExpressionValueType is 'octetString'.")
expValueOidVal = MibTableColumn((1, 3, 6, 1, 2, 1, 90, 1, 3, 1, 1, 8), ObjectIdentifier()).setMaxAccess("readonly")
if mibBuilder.loadTexts: expValueOidVal.setDescription("The value when expExpressionValueType is 'objectId'.")
expValueCounter64Val = MibTableColumn((1, 3, 6, 1, 2, 1, 90, 1, 3, 1, 1, 9), Counter64()).setMaxAccess("readonly")
if mibBuilder.loadTexts: expValueCounter64Val.setDescription("The value when expExpressionValueType is 'counter64'.")
dismanExpressionMIBConformance = MibIdentifier((1, 3, 6, 1, 2, 1, 90, 3))
dismanExpressionMIBCompliances = MibIdentifier((1, 3, 6, 1, 2, 1, 90, 3, 1))
dismanExpressionMIBGroups = MibIdentifier((1, 3, 6, 1, 2, 1, 90, 3, 2))
dismanExpressionMIBCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 90, 3, 1, 1)).setObjects(*(("DISMAN-EXPRESSION-MIB", "dismanExpressionResourceGroup"), ("DISMAN-EXPRESSION-MIB", "dismanExpressionDefinitionGroup"), ("DISMAN-EXPRESSION-MIB", "dismanExpressionValueGroup"),))
if mibBuilder.loadTexts: dismanExpressionMIBCompliance.setDescription('The compliance statement for entities which implement\n          the Expression MIB.')
dismanExpressionResourceGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 90, 3, 2, 1)).setObjects(*(("DISMAN-EXPRESSION-MIB", "expResourceDeltaMinimum"), ("DISMAN-EXPRESSION-MIB", "expResourceDeltaWildcardInstanceMaximum"), ("DISMAN-EXPRESSION-MIB", "expResourceDeltaWildcardInstances"), ("DISMAN-EXPRESSION-MIB", "expResourceDeltaWildcardInstancesHigh"), ("DISMAN-EXPRESSION-MIB", "expResourceDeltaWildcardInstanceResourceLacks"),))
if mibBuilder.loadTexts: dismanExpressionResourceGroup.setDescription('Expression definition resource management.')
dismanExpressionDefinitionGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 90, 3, 2, 2)).setObjects(*(("DISMAN-EXPRESSION-MIB", "expExpression"), ("DISMAN-EXPRESSION-MIB", "expExpressionValueType"), ("DISMAN-EXPRESSION-MIB", "expExpressionComment"), ("DISMAN-EXPRESSION-MIB", "expExpressionDeltaInterval"), ("DISMAN-EXPRESSION-MIB", "expExpressionPrefix"), ("DISMAN-EXPRESSION-MIB", "expExpressionErrors"), ("DISMAN-EXPRESSION-MIB", "expExpressionEntryStatus"), ("DISMAN-EXPRESSION-MIB", "expErrorTime"), ("DISMAN-EXPRESSION-MIB", "expErrorIndex"), ("DISMAN-EXPRESSION-MIB", "expErrorCode"), ("DISMAN-EXPRESSION-MIB", "expErrorInstance"), ("DISMAN-EXPRESSION-MIB", "expObjectID"), ("DISMAN-EXPRESSION-MIB", "expObjectIDWildcard"), ("DISMAN-EXPRESSION-MIB", "expObjectSampleType"), ("DISMAN-EXPRESSION-MIB", "expObjectDeltaDiscontinuityID"), ("DISMAN-EXPRESSION-MIB", "expObjectDiscontinuityIDWildcard"), ("DISMAN-EXPRESSION-MIB", "expObjectDiscontinuityIDType"), ("DISMAN-EXPRESSION-MIB", "expObjectConditional"), ("DISMAN-EXPRESSION-MIB", "expObjectConditionalWildcard"), ("DISMAN-EXPRESSION-MIB", "expObjectEntryStatus"),))
if mibBuilder.loadTexts: dismanExpressionDefinitionGroup.setDescription('Expression definition.')
dismanExpressionValueGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 90, 3, 2, 3)).setObjects(*(("DISMAN-EXPRESSION-MIB", "expValueCounter32Val"), ("DISMAN-EXPRESSION-MIB", "expValueUnsigned32Val"), ("DISMAN-EXPRESSION-MIB", "expValueTimeTicksVal"), ("DISMAN-EXPRESSION-MIB", "expValueInteger32Val"), ("DISMAN-EXPRESSION-MIB", "expValueIpAddressVal"), ("DISMAN-EXPRESSION-MIB", "expValueOctetStringVal"), ("DISMAN-EXPRESSION-MIB", "expValueOidVal"), ("DISMAN-EXPRESSION-MIB", "expValueCounter64Val"),))
if mibBuilder.loadTexts: dismanExpressionValueGroup.setDescription('Expression value.')
mibBuilder.exportSymbols("DISMAN-EXPRESSION-MIB", dismanExpressionMIBCompliances=dismanExpressionMIBCompliances, expExpressionComment=expExpressionComment, expObjectDiscontinuityIDType=expObjectDiscontinuityIDType, expObjectDiscontinuityIDWildcard=expObjectDiscontinuityIDWildcard, expValueTable=expValueTable, expResource=expResource, expExpressionPrefix=expExpressionPrefix, expObjectTable=expObjectTable, expValueIpAddressVal=expValueIpAddressVal, expObjectDeltaDiscontinuityID=expObjectDeltaDiscontinuityID, expErrorInstance=expErrorInstance, expObjectEntry=expObjectEntry, dismanExpressionResourceGroup=dismanExpressionResourceGroup, expObjectConditional=expObjectConditional, expExpressionEntryStatus=expExpressionEntryStatus, expExpressionTable=expExpressionTable, expValueCounter32Val=expValueCounter32Val, expErrorTable=expErrorTable, PYSNMP_MODULE_ID=dismanExpressionMIB, expExpressionDeltaInterval=expExpressionDeltaInterval, expValueInstance=expValueInstance, expExpression=expExpression, expValueTimeTicksVal=expValueTimeTicksVal, expErrorTime=expErrorTime, expResourceDeltaWildcardInstanceResourceLacks=expResourceDeltaWildcardInstanceResourceLacks, expValueEntry=expValueEntry, dismanExpressionMIB=dismanExpressionMIB, dismanExpressionMIBGroups=dismanExpressionMIBGroups, expObjectIndex=expObjectIndex, expObjectConditionalWildcard=expObjectConditionalWildcard, dismanExpressionMIBObjects=dismanExpressionMIBObjects, expValueOidVal=expValueOidVal, dismanExpressionMIBConformance=dismanExpressionMIBConformance, expResourceDeltaMinimum=expResourceDeltaMinimum, sysUpTimeInstance=sysUpTimeInstance, expResourceDeltaWildcardInstances=expResourceDeltaWildcardInstances, expExpressionEntry=expExpressionEntry, expExpressionValueType=expExpressionValueType, expObjectSampleType=expObjectSampleType, expErrorCode=expErrorCode, expDefine=expDefine, expExpressionErrors=expExpressionErrors, expValueUnsigned32Val=expValueUnsigned32Val, expValueCounter64Val=expValueCounter64Val, expExpressionOwner=expExpressionOwner, dismanExpressionDefinitionGroup=dismanExpressionDefinitionGroup, dismanExpressionMIBCompliance=dismanExpressionMIBCompliance, expObjectID=expObjectID, expErrorIndex=expErrorIndex, expResourceDeltaWildcardInstancesHigh=expResourceDeltaWildcardInstancesHigh, expValueOctetStringVal=expValueOctetStringVal, expObjectEntryStatus=expObjectEntryStatus, dismanExpressionValueGroup=dismanExpressionValueGroup, expObjectIDWildcard=expObjectIDWildcard, expExpressionName=expExpressionName, expErrorEntry=expErrorEntry, expValueInteger32Val=expValueInteger32Val, expResourceDeltaWildcardInstanceMaximum=expResourceDeltaWildcardInstanceMaximum, expValue=expValue)
